@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1994, 1995, 1997, 1998, 1999, 2000, 2001 Peter Miller;
+ *	Copyright (C) 1994, 1995, 1997-2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -81,6 +81,8 @@ enum
 	arglex_token_recursive,
 	arglex_token_recursive_not,
 	arglex_token_remove_leading_path,
+	arglex_token_stripdot,
+	arglex_token_stripdot_not,
 	arglex_token_substitute_leading_path,
 	arglex_token_suffix
 };
@@ -223,6 +225,14 @@ static	arglex_table_ty	argtab[] =
 		"-Roff",
 		(arglex_token_ty)arglex_token_lang_roff,
 	},
+	{
+		"-STripdot",
+		(arglex_token_ty)arglex_token_stripdot,
+	},
+	{
+		"-Not_STripdot",
+		(arglex_token_ty)arglex_token_stripdot_not,
+	},
 	{
 		"-System_absent",
 		(arglex_token_ty)arglex_token_absent_system_ignore,
@@ -281,6 +291,7 @@ main(argc, argv)
 	option.o_absent_program = -1;
 	option.absolute = -1;
 	option.recursive = -1;
+	option.stripdot = -1;
 	while (arglex_token != arglex_token_eoln)
 	{
 		switch(arglex_token)
@@ -524,6 +535,18 @@ main(argc, argv)
 			option.recursive = 0;
 			break;
 
+		case arglex_token_stripdot:
+			if (option.stripdot != -1)
+				goto duplicate;
+			option.stripdot = 1;
+			break;
+
+		case arglex_token_stripdot_not:
+			if (option.stripdot != -1)
+				goto duplicate;
+			option.stripdot = 0;
+			break;
+
 		case arglex_token_escape_newline:
 			if (option.escape_newline)
 				goto duplicate;
