@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1994 Peter Miller.
+ *	Copyright (C) 1994, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -15,9 +15,9 @@
  *
  *	You should have received a copy of the GNU General Public License
  *	along with this program; if not, write to the Free Software
- *	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
  *
- * MANIFEST: isolate unistd.h presnce/absence
+ * MANIFEST: insulate against <unistd.h> presence or absence
  */
 
 #ifndef COMMON_AC_UNISTD_H
@@ -25,6 +25,19 @@
 
 #include <config.h>
 
+/*
+ * Need to define _BSD_SOURCE on Linux to get prototypes for the symlink
+ * and readlink functions.
+ */
+#ifdef __linux__
+#ifndef _BSD_SOURCE
+#define _BSD_SOURCE 1
+#endif
+#ifndef __USE_BSD
+#define __USE_BSD 1
+#endif
+#endif
+
 #ifdef HAVE_UNISTD_H
 #include <sys/types.h>
 #include <unistd.h>
@@ -33,5 +46,8 @@
 #ifndef SEEK_SET
 #define SEEK_SET 0
 #endif
+#ifndef F_OK
+#define F_OK 0
+#endif
 
 #endif /* COMMON_AC_UNISTD_H */
