@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1997-1999, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -29,6 +29,15 @@
  */
 #include <ac/ctype.h>
 
+/*
+ * Often needed, particularly to implement the dummy functions if real
+ * ones aren't present.  Not strictly ANSI C standard conforming.
+ */
+#include <ac/stddef.h>
+
+/* Solaris bug 1250837: include wchar.h before widec.h */
+#include <ac/wchar.h>
+
 /*
  * Silicon Graphics
  */
@@ -38,36 +47,19 @@
 
 #ifdef HAVE_WCTYPE_H
 #include <wctype.h>
-#else
-#include <ac/stddef.h>
-/*
- * We tried to get wint_t from <stddef.h>, but not all C implementations
- * define it there, even though the ANSI C standard says they should.
- * So define it ourselves if it remains undefined.
- */
-#ifndef _TYPE_wint_t
-#ifndef _T_WINT
-#ifndef _T_WINT_
-#ifndef _WINT_T
-#ifndef __WINT_T
-#ifndef __WINT_T__
-#ifndef ___int_wint_t_h
-# define _TYPE_wint_t
-# define _T_WINT
-# define _T_WINT_
-# define _WINT_T
-# define __WINT_T
-# define __WINT_T__
-# define ___int_wint_t_h
-  typedef unsigned int wint_t;
-#endif /* ___int_wint_t_h */
-#endif /* __WINT_T__ */
-#endif /* __WINT_T */
-#endif /* _WINT_T */
-#endif /* _T_WINT_ */
-#endif /* _T_WINT */
-#endif /* _TYPE_wint_t */
+#endif
 
+/*
+ * The ANSI C standard states that wint_t symbol shall be defined by
+ * <wchar.h> and <wctype.h>.  The GNU people also define it in <stddef.h>,
+ * but this is incorrect.
+ */
+#ifndef HAVE_WINT_T
+#define HAVE_WINT_T
+typedef wchar_t wint_t;
+#endif
+
+#ifndef HAVE_WCTYPE_H
 #include <main.h>
 int iswalnum _((wint_t));
 int iswdigit _((wint_t));
@@ -80,7 +72,6 @@ wint_t towlower _((wint_t));
 wint_t towupper _((wint_t));
 #endif
 
-
 /*
  * HAVE_ISWPRINT is only set if (a) there is a have_iswprint function,
  * and (b) it works for ascii.  It is assumed that if iswprint is absent
