@@ -60,7 +60,7 @@ extern arglex_value_ty arglex_value;
 
 void arglex_init _((int argc, char **argv, arglex_table_ty *table));
 arglex_token_ty arglex _((void));
-int arglex_compare _((char *formal, char *actual));
+int arglex_compare _((const char *formal, const char *actual));
 void arglex_init_from_env _((char *argv0, arglex_table_ty *table));
 
 char *arglex_token_name _((arglex_token_ty));
