@@ -127,34 +127,29 @@ fingerprint_scan(fp, fn)
 	{
 		struct stat st;
 
-#ifdef __CYGWIN32__
-		/*
-		 * This is probably a side effect of a WindowsNT-ism.
-		 * You can't call CygWin32's open() on a directory.
-		 * This will slow us down a tad.
-		 */
-		if (stat(fn, &st) == 0 && S_ISDIR(st.st_mode))
-			return fingerprint_scan_dir(fp, fn);
-#endif
-		fd = open(fn, O_RDONLY, 0666);
-		if (fd < 0)
-			return -1;
-#ifndef __CYGWIN32__
 		/*
 		 * The most common case is to obtain a fingerprint for
-		 * a file. In the rare cases it is a directory, perform
-		 * the stat *after* the open call, and save ourselves
-		 * a second pathname walk to obtain the inode info.
+		 * a file.  In the rare case that it is a directory,
+		 * we need to do things differently.
 		 */
-		if (fstat(fd, &st) == 0 && S_ISDIR(st.st_mode))
+		if (stat(fn, &st) == 0 && S_ISDIR(st.st_mode))
 		{
-			close(fd);
 			return fingerprint_scan_dir(fp, fn);
 		}
-#endif
+
+		/*
+		 * Assume it's a normal file.
+		 * (Slow things will happen if, say, it's a tape device.)
+		 */
+		fd = open(fn, O_RDONLY|O_BINARY, 0666);
+		if (fd < 0)
+			return -1;
+
 	}
 	else
+	{
 		fd = 0;
+	}
 	for (;;)
 	{
 		nbytes = read(fd, ibuf, sizeof(ibuf));
