@@ -212,17 +212,8 @@ generic_argument(usage)
 	case arglex_token_page_length:
 		if (arglex() != arglex_token_number)
 		{
-			scp = sub_context_new();
-			sub_var_set
-			(
-				scp,
-				"Name",
-				"%s",
-				arglex_token_name(arglex_token_page_length)
-			);
-			error_intl(scp, i18n("$name needs number"));
-			sub_context_delete(scp);
-			usage();
+			arg_needs_number(arglex_token_page_length, usage);
+			/* NOTREACHED */
 		}
 		page_length_set(arglex_value.alv_number);
 		arglex();
@@ -231,17 +222,8 @@ generic_argument(usage)
 	case arglex_token_page_width:
 		if (arglex() != arglex_token_number)
 		{
-			scp = sub_context_new();
-			sub_var_set
-			(
-				scp,
-				"Name",
-				"%s",
-				arglex_token_name(arglex_token_page_width)
-			);
-			error_intl(scp, i18n("$name needs number"));
-			sub_context_delete(scp);
-			usage();
+			arg_needs_number(arglex_token_page_width, usage);
+			/* NOTREACHED */
 		}
 		page_width_set(arglex_value.alv_number);
 		arglex();
@@ -339,3 +321,75 @@ bad_argument(usage)
 	quit(1);
 	/* NOTREACHED */
 }
+
+
+void
+arg_duplicate(n, usage)
+	int		n;
+	void		(*usage)_((void));
+{
+	sub_context_ty	*scp;
+
+	scp = sub_context_new();
+	sub_var_set(scp, "Name", "%s", arglex_token_name(n));
+	if (!usage)
+	{
+		fatal_intl(scp, i18n("duplicate \"$name\" option"));
+		/* NOTREACHED */
+	}
+	error_intl(scp, i18n("duplicate \"$name\" option"));
+	sub_context_delete(scp);
+	usage();
+	/* NOTREACHED */
+}
+
+
+void
+arg_duplicate_cur(usage)
+	void		(*usage)_((void));
+{
+	arg_duplicate(arglex_token, usage);
+	/* NOTREACHED */
+}
+
+
+void
+arg_needs_string(n, usage)
+	int		n;
+	void		(*usage)_((void));
+{
+	sub_context_ty	*scp;
+
+	scp = sub_context_new();
+	sub_var_set(scp, "Name", "%s", arglex_token_name(n));
+	if (!usage)
+	{
+		fatal_intl(scp, i18n("$name needs string"));
+		/* NOTREACHED */
+	}
+	error_intl(scp, i18n("$name needs string"));
+	sub_context_delete(scp);
+	usage();
+	/* NOTREACHED */
+}
+
+
+void
+arg_needs_number(n, usage)
+	int		n;
+	void		(*usage)_((void));
+{
+	sub_context_ty	*scp;
+
+	scp = sub_context_new();
+	sub_var_set(scp, "Name", "%s", arglex_token_name(n));
+	if (!usage)
+	{
+		fatal_intl(scp, i18n("$name needs number"));
+		/* NOTREACHED */
+	}
+	error_intl(scp, i18n("$name needs number"));
+	sub_context_delete(scp);
+	usage();
+	/* NOTREACHED */
+}
