@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 2001 Peter Miller;
+ *	Copyright (C) 1997, 2001, 2003 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -41,20 +41,17 @@ struct itab_ty
 	void		(*reap)_((void *));
 	itab_row_ty	**hash_table;
 	itab_key_ty	hash_modulus;
-	itab_key_ty	hash_cutover;
-	itab_key_ty	hash_cutover_mask;
-	itab_key_ty	hash_cutover_split_mask;
-	itab_key_ty	hash_split;
+	itab_key_ty	hash_mask;
 	itab_key_ty	load;
 };
 
-itab_ty *itab_alloc _((int));
-void itab_free _((itab_ty *));
-void *itab_query _((itab_ty *, itab_key_ty));
-void itab_assign _((itab_ty *, itab_key_ty, void *));
-void itab_delete _((itab_ty *, itab_key_ty));
-void itab_walk _((itab_ty *,
+itab_ty *itab_alloc(int);
+void itab_free(itab_ty *);
+void *itab_query(itab_ty *, itab_key_ty);
+void itab_assign(itab_ty *, itab_key_ty, void *);
+void itab_delete(itab_ty *, itab_key_ty);
+void itab_walk(itab_ty *,
 	void (*)(itab_ty *, itab_key_ty, void *, void *),
-	void *));
+	void *);
 
 #endif /* COMMON_ITAB_H */
