@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1999 Peter Miller;
+ *	Copyright (C) 1997, 1999, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -24,29 +24,36 @@
 #include <libdir.h>
 
 
-char *
+const char *
 library_directory_get()
 {
 	return LIBDIR;
 }
 
 
-char *
+const char *
 data_directory_get()
 {
 	return DATADIR;
 }
 
 
-char *
+const char *
 manual_directory_get()
 {
 	return MANDIR;
 }
 
 
-char *
+const char *
 executable_extension_get()
 {
 	return EXEEXT;
 }
+
+
+const char *
+configured_nlsdir()
+{
+    return NLSDIR;
+}
