@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1999 Peter Miller;
+ *	Copyright (C) 1997, 1999, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,9 +25,10 @@
 
 #include <main.h>
 
-char *library_directory_get _((void));
-char *data_directory_get _((void));
-char *manual_directory_get _((void));
-char *executable_extension_get _((void));
+const char *library_directory_get _((void));
+const char *data_directory_get _((void));
+const char *manual_directory_get _((void));
+const char *executable_extension_get _((void));
+const char *configured_nlsdir _((void));
 
 #endif /* COMMON_LIBDIR_H */
