@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1991, 1992, 1993, 1994, 1997, 1999 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1997, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -257,7 +257,7 @@ vmprintf(fmt, ap)
 			c = *s++;
 			width_set = 1;
 			break;
-		
+
 		case '0': case '1': case '2': case '3': case '4':
 		case '5': case '6': case '7': case '8': case '9':
 			for (;;)
@@ -503,7 +503,9 @@ vmprintf(fmt, ap)
 					break;
 
 				case 'h':
-					a = (unsigned short)va_arg(ap, unsigned int);
+					a =
+						(unsigned short)
+						va_arg(ap, unsigned int);
 					break;
 
 				default:
