@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1999 Peter Miller;
+ *	Copyright (C) 1997, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -26,6 +26,9 @@
 #include <star.h>
 
 
+static quit_ty	quit_list_prio[4];
+static int	quit_list_prio_length;
+
 static quit_ty	quit_list[32];
 static int	quit_list_length;
 
@@ -51,6 +54,15 @@ quit_handler(f)
 		quit_list[quit_list_length++] = f;
 }
 
+void
+quit_handler_prio(f)
+	quit_ty		f;
+{
+	/* assert(quit_list_prio_length < SIZEOF(quit_list)); */
+	if (quit_list_prio_length < SIZEOF(quit_list))
+		quit_list_prio[quit_list_prio_length++] = f;
+}
+
 
 /*
  * NAME
@@ -76,6 +88,8 @@ quit(n)
 	int		n;
 {
 	star_eoln();
+	while (quit_list_prio_length > 0)
+		(*quit_list_prio[--quit_list_prio_length])();
 	while (quit_list_length > 0)
 		(*quit_list[--quit_list_length])();
 	exit(n);
