@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1993, 1994, 1995, 1997, 1998, 1999, 2001 Peter Miller;
+ *	Copyright (C) 1993-1995, 1997-1999, 2001, 2003 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -53,10 +53,7 @@ string_ty *str_true;
 string_ty *str_false;
 static string_ty **hash_table;
 static str_hash_ty hash_modulus;
-static str_hash_ty hash_cutover;
-static str_hash_ty hash_cutover_mask;
-static str_hash_ty hash_cutover_split_mask;
-static str_hash_ty hash_split;
+static str_hash_ty hash_mask;
 static str_hash_ty hash_load;
 
 #define MAX_HASH_LEN 20
@@ -80,28 +77,24 @@ static str_hash_ty hash_load;
  *	It is important that str_hash_ty be unsigned (int or long).
  */
 
-static str_hash_ty hash_generate _((const char *, size_t));
-
 static str_hash_ty
-hash_generate(s, n)
-	const char	*s;
-	size_t		n;
+hash_generate(const char *s, size_t n)
 {
-	str_hash_ty	retval;
+    str_hash_ty     retval;
 
-	if (n > MAX_HASH_LEN)
-	{
-		s += n - MAX_HASH_LEN;
-		n = MAX_HASH_LEN;
-	}
+    if (n > MAX_HASH_LEN)
+    {
+	s += n - MAX_HASH_LEN;
+	n = MAX_HASH_LEN;
+    }
 
-	retval = 0;
-	while (n > 0)
-	{
-		retval = (retval + (retval << 1)) ^ *s++;
-		--n;
-	}
-	return retval;
+    retval = 0;
+    while (n > 0)
+    {
+	retval = (retval + (retval << 1)) ^ *s++;
+	--n;
+    }
+    return retval;
 }
 
 
@@ -126,57 +119,53 @@ hash_generate(s, n)
 #ifdef DEBUG
 
 int
-str_valid(s)
-	string_ty	*s;
+str_valid(string_ty *s)
 {
-	return
-	(
-		s->str_references > 0
-	&&
-		strlen(s->str_text) == s->str_length
-	&&
-		s->str_hash == hash_generate(s->str_text, s->str_length)
-	);
+return
+(
+    s->str_references > 0
+&&
+    strlen(s->str_text) == s->str_length
+&&
+    s->str_hash == hash_generate(s->str_text, s->str_length)
+);
 }
 
 #endif
 
 
 /*
- * NAME
- *	str_initialize - start up string table
- *
- * SYNOPSIS
- *	void str_initialize(void);
- *
- * DESCRIPTION
- *	The str_initialize function is used to create the hash table and
- *	initialize it to empty.
- *
- * RETURNS
- *	void
- *
- * CAVEAT
- *	This function must be called before any other defined in this file.
- */
+* NAME
+*	str_initialize - start up string table
+*
+* SYNOPSIS
+*	void str_initialize(void);
+*
+* DESCRIPTION
+*	The str_initialize function is used to create the hash table and
+*	initialize it to empty.
+*
+* RETURNS
+*	void
+*
+* CAVEAT
+*	This function must be called before any other defined in this file.
+*/
 
 void
-str_initialize()
+str_initialize(void)
 {
-	str_hash_ty	j;
+    str_hash_ty     j;
 
-	hash_modulus = 1 << 8; /* MUST be a power of 2 */
-	hash_cutover = hash_modulus;
-	hash_split = hash_modulus - hash_cutover;
-	hash_cutover_mask = hash_cutover - 1;
-	hash_cutover_split_mask = (hash_cutover * 2) - 1;
-	hash_load = 0;
-	hash_table = mem_alloc(hash_modulus * sizeof(string_ty *));
-	for (j = 0; j < hash_modulus; ++j)
-		hash_table[j] = 0;
+    hash_modulus = 1 << 8; /* MUST be a power of 2 */
+    hash_mask = hash_modulus - 1;
+    hash_load = 0;
+    hash_table = mem_alloc(hash_modulus * sizeof(string_ty *));
+    for (j = 0; j < hash_modulus; ++j)
+	    hash_table[j] = 0;
 
-	str_true = str_from_c("1");
-	str_false = str_from_c("");
+    str_true = str_from_c("1");
+    str_false = str_from_c("");
 }
 
 
@@ -197,56 +186,60 @@ str_initialize()
  *	A load factor of about 80% is suggested.
  */
 
-static void split _((void));
-
 static void
-split()
+split(void)
 {
-	string_ty	*p;
-	string_ty	*p2;
-	str_hash_ty	idx;
+    string_ty       **new_hash_table;
+    str_hash_ty     new_hash_modulus;
+    str_hash_ty     new_hash_mask;
+    str_hash_ty     j;
 
-	/*
-	 * get the list to be split across buckets
-	 */
-	p = hash_table[hash_split];
-	hash_table[hash_split] = 0;
+    /*
+     * double the modulus
+     *
+     * This is subtle.  If we only increase the modulus by one, the
+     * load always hovers around 80%, so we have to do a split for
+     * every insert.  I.e. the malloc burden is O(n) for the lifetime of
+     * the program.  BUT if we double the modulus, the length of time
+     * until the next split also doubles, making the probablity of a
+     * split halve, and sigma(2**-n)=1, so the malloc burden becomes O(1)
+     * for the lifetime of the program.
+     */
+    new_hash_modulus = hash_modulus << 1;
+    new_hash_mask = new_hash_modulus - 1;
+    new_hash_table = mem_alloc(new_hash_modulus * sizeof(string_ty *));
 
-	/*
-	 * increase the modulus by one
-	 */
-	hash_modulus++;
-	hash_table =
-		mem_change_size
-		(
-			hash_table,
-			hash_modulus * sizeof(string_ty *)
-		);
-	hash_table[hash_modulus - 1] = 0;
-	hash_split = hash_modulus - hash_cutover;
-	if (hash_split >= hash_cutover)
-	{
-		hash_cutover = hash_modulus;
-		hash_split = 0;
-		hash_cutover_mask = hash_cutover - 1;
-		hash_cutover_split_mask = (hash_cutover * 2) - 1;
-	}
+    /*
+     * now redistribute the list elements
+     */
+    for (j = 0; j < hash_modulus; ++j)
+    {
+	string_ty       *p;
 
-	/*
-	 * now redistribute the list elements
-	 */
+	p = hash_table[j];
+	new_hash_table[j] = 0;
+	new_hash_table[hash_modulus + j] = 0;
 	while (p)
 	{
-		p2 = p;
-		p = p->str_next;
+	    string_ty       *p2;
+	    str_hash_ty     idx;
 
-		idx = p2->str_hash & hash_cutover_mask;
-		if (idx < hash_split)
-			idx = p2->str_hash & hash_cutover_split_mask;
-		assert(idx < hash_modulus);
-		p2->str_next = hash_table[idx];
-		hash_table[idx] = p2;
+	    p2 = p;
+	    p = p->str_next;
+
+	    idx = p2->str_hash & new_hash_mask;
+	    p2->str_next = new_hash_table[idx];
+	    new_hash_table[idx] = p2;
 	}
+    }
+
+    /*
+     * swap it over
+     */
+    mem_free(hash_table);
+    hash_table = new_hash_table;
+    hash_modulus = new_hash_modulus;
+    hash_mask = new_hash_mask;
 }
 
 
@@ -270,10 +263,9 @@ split()
  */
 
 string_ty *
-str_from_c(s)
-	const char	*s;
+str_from_c(const char *s)
 {
-	return str_n_from_c(s, strlen(s));
+    return str_n_from_c(s, strlen(s));
 }
 
 
@@ -297,65 +289,61 @@ str_from_c(s)
  */
 
 string_ty *
-str_n_from_c(s, length)
-	const char	*s;
-	size_t		length;
+str_n_from_c(const char *s, size_t length)
 {
-	str_hash_ty	hash;
-	str_hash_ty	idx;
-	string_ty	*p;
+    str_hash_ty     hash;
+    str_hash_ty     idx;
+    string_ty       *p;
 
-	hash = hash_generate(s, length);
+    hash = hash_generate(s, length);
 
 #ifdef DEBUG
-	if (!hash_table)
-		fatal_raw("you must call str_initialize early in main()");
+    if (!hash_table)
+	fatal_raw("you must call str_initialize early in main()");
 #endif
-	idx = hash & hash_cutover_mask;
-	if (idx < hash_split)
-		idx = hash & hash_cutover_split_mask;
-	assert(idx < hash_modulus);
+    idx = hash & hash_mask;
+    assert(idx < hash_modulus);
 
-	for (p = hash_table[idx]; p; p = p->str_next)
+    for (p = hash_table[idx]; p; p = p->str_next)
+    {
+	if
+	(
+	    p->str_hash == hash
+	&&
+	    p->str_length == length
+	&&
+	    0 == memcmp(p->str_text, s, length)
+	)
 	{
-		if
-		(
-			p->str_hash == hash
-		&&
-			p->str_length == length
-		&&
-			0 == memcmp(p->str_text, s, length)
-		)
-		{
-			p->str_references++;
-			return p;
-		}
+	    p->str_references++;
+	    return p;
 	}
+    }
 
-	p = mem_alloc(sizeof(string_ty) + length);
-	p->str_hash = hash;
-	p->str_length = length;
-	p->str_references = 1;
-	p->str_next = hash_table[idx];
-	hash_table[idx] = p;
+    p = mem_alloc(sizeof(string_ty) + length);
+    p->str_hash = hash;
+    p->str_length = length;
+    p->str_references = 1;
+    p->str_next = hash_table[idx];
+    hash_table[idx] = p;
 #if 0
-	/* silence purify */
-	{
-		/*
-		 * probably sizeof(int) bytes,
-		 * but is compiler dependent
-		 */
-		size_t n = sizeof(string_ty) - offsetof(string_ty, str_text);
-		memset(p->str_text, 0, n);
-	}
+    /* silence purify */
+    {
+	    /*
+	     * probably sizeof(int) bytes,
+	     * but is compiler dependent
+	     */
+	    size_t n = sizeof(string_ty) - offsetof(string_ty, str_text);
+	    memset(p->str_text, 0, n);
+    }
 #endif
-	memcpy(p->str_text, s, length);
-	p->str_text[length] = 0;
+    memcpy(p->str_text, s, length);
+    p->str_text[length] = 0;
 
-	hash_load++;
-	while (hash_load * 10 > hash_modulus * 8)
-		split();
-	return p;
+    hash_load++;
+    if (hash_load * 10 > hash_modulus * 8)
+	split();
+    return p;
 }
 
 
@@ -378,11 +366,10 @@ str_n_from_c(s, length)
  */
 
 string_ty *
-str_copy(s)
-	string_ty	*s;
+str_copy(string_ty *s)
 {
-	s->str_references++;
-	return s;
+    s->str_references++;
+    return s;
 }
 
 
@@ -405,40 +392,37 @@ str_copy(s)
  */
 
 void
-str_free(s)
-	string_ty	*s;
+str_free(string_ty *s)
 {
-	str_hash_ty	idx;
-	string_ty	**spp;
+    str_hash_ty     idx;
+    string_ty       **spp;
 
-	assert(str_valid(s));
-	if (s->str_references > 1)
-	{
-		s->str_references--;
-		return;
-	}
-	assert(s->str_references == 1);
+    assert(str_valid(s));
+    if (s->str_references > 1)
+    {
+	s->str_references--;
+	return;
+    }
+    assert(s->str_references == 1);
 
-	/*
-	 *  find the hash bucket it was in,
-	 *  and remove it
-	 */
-	idx = s->str_hash & hash_cutover_mask;
-	if (idx < hash_split)
-		idx = s->str_hash & hash_cutover_split_mask;
-	assert(idx < hash_modulus);
-	for (spp = &hash_table[idx]; *spp; spp = &(*spp)->str_next)
+    /*
+     * find the hash bucket it was in,
+     * and remove it
+     */
+    idx = s->str_hash & hash_mask;
+    assert(idx < hash_modulus);
+    for (spp = &hash_table[idx]; *spp; spp = &(*spp)->str_next)
+    {
+	if (*spp == s)
 	{
-		if (*spp == s)
-		{
-			*spp = s->str_next;
-			free(s);
-			--hash_load;
-			return;
-		}
+	    *spp = s->str_next;
+	    free(s);
+	    --hash_load;
+	    return;
 	}
-	/* should never reach here! */
-	fatal_raw("attempted to free non-existent string (bug)");
+    }
+    /* should never reach here! */
+    fatal_raw("attempted to free non-existent string (bug)");
 }
 
 
@@ -463,11 +447,9 @@ str_free(s)
 #ifndef str_equal
 
 int
-str_equal(s1, s2)
-	string_ty	*s1;
-	string_ty	*s2;
+str_equal(string_ty *s1, string_ty *s2)
 {
-	return (s1 == s2);
+    return (s1 == s2);
 }
 
 #endif
@@ -491,19 +473,18 @@ str_equal(s1, s2)
  */
 
 int
-str_bool(s)
-	string_ty	*s;
+str_bool(string_ty *s)
 {
-	char		*cp;
+    char        *cp;
 
-	cp = s->str_text;
-	while (*cp)
-	{
-		if (*cp != ' ' && *cp != '0')
-			return 1;
-		++cp;
-	}
-	return 0;
+    cp = s->str_text;
+    while (*cp)
+    {
+	if (*cp != ' ' && *cp != '0')
+    	    return 1;
+	++cp;
+    }
+    return 0;
 }
 
 
@@ -525,27 +506,24 @@ str_bool(s)
  */
 
 string_ty *
-str_field(s, sep, fldnum)
-	string_ty	*s;
-	int		sep;
-	int		fldnum;
+str_field(string_ty *s, int sep, int fldnum)
 {
-	char		*cp;
-	char		*ep;
+    char        *cp;
+    char        *ep;
 
-	cp = s->str_text;
-	while (fldnum > 0)
-	{
-		ep = strchr(cp, sep);
-		if (!ep)
-			return 0;
-		cp = ep + 1;
-		--fldnum;
-	}
+    cp = s->str_text;
+    while (fldnum > 0)
+    {
 	ep = strchr(cp, sep);
-	if (ep)
-		return str_n_from_c(cp, ep - cp);
-	return str_from_c(cp);
+	if (!ep)
+    	    return 0;
+	cp = ep + 1;
+	--fldnum;
+    }
+    ep = strchr(cp, sep);
+    if (ep)
+	return str_n_from_c(cp, ep - cp);
+    return str_from_c(cp);
 }
 
 
@@ -568,30 +546,22 @@ str_field(s, sep, fldnum)
 
 
 string_ty *
-#if defined(__STDC__) && __STDC__
 str_format(const char *fmt, ...)
-#else
-str_format(fmt sva_last)
-	const char	*fmt;
-	sva_last_decl
-#endif
 {
-	va_list		ap;
-	string_ty	*result;
+    va_list         ap;
+    string_ty       *result;
 
-	sva_init(ap, fmt);
-	result = vmprintfes(fmt, ap);
-	va_end(ap);
-	return result;
-	/* to silence debug warning */
-	trace(("bogus\n"));
+    sva_init(ap, fmt);
+    result = vmprintfes(fmt, ap);
+    va_end(ap);
+    return result;
+    /* to silence debug warning */
+    trace(("bogus\n"));
 }
 
 
 string_ty *
-str_vformat(fmt, ap)
-	const char	*fmt;
-	va_list		ap;
+str_vformat(const char *fmt, va_list ap)
 {
-	return vmprintfes(fmt, ap);
+    return vmprintfes(fmt, ap);
 }
