@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1991, 1992, 1993, 1994, 1997, 2000 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1997, 2000, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -43,7 +43,8 @@ void string_list_append _((string_list_ty *, string_ty *));
 void string_list_append_list _((string_list_ty *, const string_list_ty *));
 void string_list_prepend _((string_list_ty *, string_ty *));
 void string_list_append_unique _((string_list_ty *, string_ty *));
-void string_list_append_list_unique _((string_list_ty *, const string_list_ty *));
+void string_list_append_list_unique _((string_list_ty *,
+	const string_list_ty *));
 void string_list_copy_constructor _((string_list_ty *, const string_list_ty *));
 void string_list_remove _((string_list_ty *, string_ty *));
 void string_list_remove_list _((string_list_ty *, const string_list_ty *));
