@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1997, 1998, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -43,9 +43,9 @@
  *	wstring_ty *sub_errno(wstring_list_ty *arg);
  *
  * DESCRIPTION
- *	The sub_errno function implements the errno substitution.
- *	The errno substitution is replaced by the value if th errno
- *	variable provided by the system, as mapped through the strerror function.
+ *	The sub_errno function implements the errno substitution.  The
+ *	errno substitution is replaced by the value if th errno variable
+ *	provided by the system, as mapped through the strerror function.
  *
  *	Requires exactly zero arguments.
  *
