@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1999 Peter Miller;
+ *	Copyright (C) 1997, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -133,7 +133,8 @@ wstr_initialize()
 	hash_cutover_mask = hash_cutover - 1;
 	hash_cutover_split_mask = (hash_cutover * 2) - 1;
 	hash_load = 0;
-	hash_table = (wstring_ty **)mem_alloc(hash_modulus * sizeof(wstring_ty *));
+	hash_table =
+		(wstring_ty **)mem_alloc(hash_modulus * sizeof(wstring_ty *));
 	for (j = 0; j < hash_modulus; ++j)
 		hash_table[j] = 0;
 }
@@ -176,7 +177,11 @@ split()
 	 */
 	hash_modulus++;
 	hash_table =
-		mem_change_size(hash_table, hash_modulus * sizeof(wstring_ty *));
+		mem_change_size
+		(
+			hash_table,
+			hash_modulus * sizeof(wstring_ty *)
+		);
 	hash_table[hash_modulus - 1] = 0;
 	hash_split = hash_modulus - hash_cutover;
 	if (hash_split >= hash_cutover)
@@ -555,7 +560,9 @@ wstr_n_from_wc(s, length)
 		}
 	}
 
-	p = (wstring_ty *)mem_alloc(sizeof(wstring_ty) + length * sizeof(wchar_t));
+	p =
+		(wstring_ty *)
+		mem_alloc(sizeof(wstring_ty) + length * sizeof(wchar_t));
 	p->wstr_hash = hash;
 	p->wstr_length = length;
 	p->wstr_references = 1;
@@ -583,8 +590,8 @@ wstr_n_from_wc(s, length)
  *	The wstr_copy function is used to make a copy of a string.
  *
  * RETURNS
- *	wstring_ty* - a pointer to a string in dynamic memory.  Use wstr_free when
- *	finished with.
+ *	wstring_ty* - a pointer to a string in dynamic memory.
+ *	Use wstr_free when finished with.
  *
  * CAVEAT
  *	The contents of the structure pointed to MUST NOT be altered.
@@ -670,8 +677,8 @@ wstr_free(s)
  *	new string.
  *
  * RETURNS
- *	wstring_ty* - a pointer to a string in dynamic memory.  Use wstr_free when
- *	finished with.
+ *	wstring_ty* - a pointer to a string in dynamic memory.
+ *	Use wstr_free when finished with.
  *
  * CAVEAT
  *	The contents of the structure pointed to MUST NOT be altered.
@@ -694,7 +701,12 @@ wstr_catenate(s1, s2)
 		tmp = mem_change_size(tmp, tmplen * sizeof(wchar_t));
 	}
 	memcpy(tmp, s1->wstr_text, s1->wstr_length * sizeof(wchar_t));
-	memcpy(tmp + s1->wstr_length, s2->wstr_text, s2->wstr_length * sizeof(wchar_t));
+	memcpy
+	(
+		tmp + s1->wstr_length,
+		s2->wstr_text,
+		s2->wstr_length * sizeof(wchar_t)
+	);
 	s = wstr_n_from_wc(tmp, length);
 	return s;
 }
@@ -712,8 +724,8 @@ wstr_catenate(s1, s2)
  *	a new string.
  *
  * RETURNS
- *	wstring_ty* - a pointer to a string in dynamic memory.  Use wstr_free when
- *	finished with.
+ *	wstring_ty* - a pointer to a string in dynamic memory.
+ *	Use wstr_free when finished with.
  *
  * CAVEAT
  *	The contents of the structure pointed to MUST NOT be altered.
