@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1991, 1992, 1993, 1994, 1997, 1998 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1997, 1998, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -59,8 +59,11 @@
  *	'then' and 'else' cant be escaped, sorry.
  */
 
-int
-builtin_if(result, args, pp, ocp)
+static int if_interpret _((string_list_ty *, const string_list_ty *,
+	const expr_position_ty *, const struct opcode_context_ty *));
+
+static int
+if_interpret(result, args, pp, ocp)
 	string_list_ty	*result;
 	const string_list_ty *args;
 	const expr_position_ty *pp;
@@ -149,6 +152,14 @@ builtin_if(result, args, pp, ocp)
 }
 
 
+builtin_ty builtin_if =
+{
+	"if",
+	if_interpret,
+	if_interpret, /* script */
+};
+
+
 /*
  * NAME
  *	builtin_not - logical negation
@@ -171,8 +182,11 @@ builtin_if(result, args, pp, ocp)
  *	the result when it is finished, with a string_list_destructor() call.
  */
 
-int
-builtin_not(result, args, pp, ocp)
+static int not_interpret _((string_list_ty *, const string_list_ty *,
+	const expr_position_ty *, const struct opcode_context_ty *));
+
+static int
+not_interpret(result, args, pp, ocp)
 	string_list_ty	*result;
 	const string_list_ty *args;
 	const expr_position_ty *pp;
@@ -197,6 +211,14 @@ builtin_not(result, args, pp, ocp)
 }
 
 
+builtin_ty builtin_not =
+{
+	"not",
+	not_interpret,
+	not_interpret, /* script */
+};
+
+
 /*
  * NAME
  *	builtin_and - logical conjunction
@@ -219,8 +241,11 @@ builtin_not(result, args, pp, ocp)
  *	the result when it is finished, with a string_list_destructor() call.
  */
 
-int
-builtin_and(result, args, pp, ocp)
+static int and_interpret _((string_list_ty *, const string_list_ty *,
+	const expr_position_ty *, const struct opcode_context_ty *));
+
+static int
+and_interpret(result, args, pp, ocp)
 	string_list_ty	*result;
 	const string_list_ty *args;
 	const expr_position_ty *pp;
@@ -260,6 +285,14 @@ builtin_and(result, args, pp, ocp)
 }
 
 
+builtin_ty builtin_and =
+{
+	"and",
+	and_interpret,
+	and_interpret, /* script */
+};
+
+
 /*
  * NAME
  *	builtin_or - logical disjunction
@@ -282,8 +315,11 @@ builtin_and(result, args, pp, ocp)
  *	the result when it is finished, with a string_list_destructor() call.
  */
 
-int
-builtin_or(result, args, pp, ocp)
+static int or_interpret _((string_list_ty *, const string_list_ty *,
+	const expr_position_ty *, const struct opcode_context_ty *));
+
+static int
+or_interpret(result, args, pp, ocp)
 	string_list_ty	*result;
 	const string_list_ty *args;
 	const expr_position_ty *pp;
@@ -323,6 +359,14 @@ builtin_or(result, args, pp, ocp)
 }
 
 
+builtin_ty builtin_or =
+{
+	"or",
+	or_interpret,
+	or_interpret, /* script */
+};
+
+
 /*
  * NAME
  *	builtin_in - test for set membership
@@ -344,14 +388,17 @@ builtin_or(result, args, pp, ocp)
  *	the result when it is finished, with a string_list_destructor() call.
  */
 
-int
-builtin_in(result, args, pp, ocp)
+static int in_interpret _((string_list_ty *, const string_list_ty *,
+	const expr_position_ty *, const struct opcode_context_ty *));
+
+static int
+in_interpret(result, args, pp, ocp)
 	string_list_ty	*result;
 	const string_list_ty *args;
 	const expr_position_ty *pp;
 	const struct opcode_context_ty *ocp;
 {
-	int		j;
+	size_t		j;
 
 	assert(result);
 	assert(args);
@@ -375,10 +422,22 @@ builtin_in(result, args, pp, ocp)
 	{
 		if (str_equal(args->string[1], args->string[j]))
 		{
-			string_list_append(result, str_true);
+			string_ty	*s;
+
+			s = str_format("%ld", (long)j - 1);
+			string_list_append(result, s);
+			str_free(s);
 			return 0;
 		}
 	}
 	string_list_append(result, str_false);
 	return 0;
 }
+
+
+builtin_ty builtin_in =
+{
+	"in",
+	in_interpret,
+	in_interpret, /* script */
+};
