@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1994, 1997, 1998 Peter Miller;
+ *	Copyright (C) 1994, 1997, 1998, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -23,16 +23,9 @@
 #ifndef COOK_BUILTIN_EXISTS_H
 #define COOK_BUILTIN_EXISTS_H
 
-#include <main.h>
+#include <builtin/private.h>
 
-struct string_list_ty; /* existence */
-struct expr_position_ty; /* existence */
-struct opcode_context_ty; /* existence */
-
-int builtin_exists _((struct string_list_ty *, const struct string_list_ty *,
-	const struct expr_position_ty *, const struct opcode_context_ty *));
-int builtin_exists_symlink _((struct string_list_ty *,
-	const struct string_list_ty *, const struct expr_position_ty *,
-	const struct opcode_context_ty *));
+extern builtin_ty builtin_exists;
+extern builtin_ty builtin_exists_symlink;
 
 #endif /* COOK_BUILTIN_EXISTS_H */
