@@ -49,7 +49,7 @@
 #include <error_intl.h>
 #include <exeext.h>
 #include <expr/position.h>
-#include <os.h>
+#include <os_interface.h>
 #include <trace.h>
 
 
