@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1994, 1997, 1998 Peter Miller;
+ *	Copyright (C) 1994, 1997, 1998, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -53,8 +53,11 @@ contains(s1, s2)
 }
 
 
-int
-builtin_findstring(result, arg, pp, ocp)
+static int interpret _((string_list_ty *, const string_list_ty *,
+	const expr_position_ty *, const struct opcode_context_ty *));
+
+static int
+interpret(result, arg, pp, ocp)
 	string_list_ty	*result;
 	const string_list_ty *arg;
 	const expr_position_ty *pp;
@@ -87,3 +90,11 @@ builtin_findstring(result, arg, pp, ocp)
 	}
 	return 0;
 }
+
+
+builtin_ty builtin_findstring =
+{
+	"findstring",
+	interpret,
+	interpret, /* script */
+};
