@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1991, 1992, 1993, 1994, 1996, 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1993, 1994, 1996, 1997, 1998, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -112,7 +112,8 @@ globber(formal, pp)
 			size_t		n;
 
 			/* nothing special */
-			trace(("ordinary = \"%.*s\";\n", formal_end - formal, formal));
+			trace(("ordinary = \"%.*s\";\n",
+				formal_end - formal, formal));
 			for (cp = formal; cp < formal_end; ++cp)
 				sa_char(&temp, *cp);
 			n = sa_mark(&temp);
@@ -129,7 +130,13 @@ globber(formal, pp)
 				{
 					scp = sub_context_new();
 					sub_errno_set(scp);
-					sub_var_set(scp, "File_Name", "%s", temp.sa_buf);
+					sub_var_set
+					(
+						scp,
+						"File_Name",
+						"%s",
+						temp.sa_buf
+					);
 					error_with_position
 					(
 						pp,
@@ -151,7 +158,8 @@ globber(formal, pp)
 				string_ty *s;
 
 				s = sa_close(&temp);
-				temp.sa_inuse = 1; /* defeat assert protection */
+				/* defeat assert protection */
+				temp.sa_inuse = 1;
 				string_list_append(where, s);
 				str_free(s);
 				break;
@@ -165,7 +173,8 @@ globber(formal, pp)
 			struct dirent	*dep;
 
 			/* need to expand wild characters */
-			trace(("expand = \"%.*s\";\n", formal_end - formal, formal));
+			trace(("expand = \"%.*s\";\n",
+				formal_end - formal, formal));
 			n = sa_mark(&temp);
 			sa_char(&temp, 0);
 			dp = opendir(n ? temp.sa_buf : ".");
@@ -175,7 +184,13 @@ globber(formal, pp)
 					break;
 				scp = sub_context_new();
 				sub_errno_set(scp);
-				sub_var_set(scp, "File_Name", "%s", temp.sa_buf);
+				sub_var_set
+				(
+					scp,
+					"File_Name",
+					"%s",
+					temp.sa_buf
+				);
 				error_with_position
 				(
 					pp,
@@ -203,7 +218,7 @@ globber(formal, pp)
 						!np[1]
 					||
 						(np[1] == '.' && !np[2])
-					)  
+					)
 				)
 					continue;
 				trace(("filename = \"%s\"\n", np));
@@ -223,7 +238,8 @@ globber(formal, pp)
 					string_ty *s;
 
 					s = sa_close(&temp);
-					temp.sa_inuse = 1; /* defeat assert protection */
+					/* defeat assert protection */
+					temp.sa_inuse = 1;
 					string_list_append(where, s);
 					str_free(s);
 				}
