@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1996, 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1996-1999, 2003 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -18,6 +18,40 @@
  *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
  *
  * MANIFEST: functions to implement the builtin options function
+ *
+ *
+ * If you are going to add a new recipe flag (set by the "set" statement,
+ * or the "set" clause of a recipe) you need to change all of the
+ * following places:
+ *
+ * cook/option.h
+ *     to define the OPTION_ value
+ * cook/option.c
+ *     option_tidyup()
+ *         if the option defaults to true
+ *     option_set_errors()
+ *         if the option should be turned off once cookbook errors
+ *         are encountered.
+ *     option_number_name()
+ *         for the name of the option
+ * cook/flag.h
+ *     to define the RF_ values (RF stands for Recipe Flag)
+ * cook/flag.c
+ *     to define the RF_ names
+ * langu.flags.so
+ *     to document the recipe flag
+ *
+ * If you choose to make it a command line option,
+ * you must also update these files:
+ *
+ * cook/main.c
+ *     to define the new command line option and process it
+ *     (only if it should also be a command line option)
+ * cook/builtin/options.c
+ *     to access the option from within the cookbook (typically used
+ *     for recursive cook invokations)
+ * lib/en/man1/cook.1
+ *     to document it, if you added a new command line option
  */
 
 #include <builtin/options.h>
@@ -54,6 +88,7 @@ static table_ty table[] =
 	{ OPTION_TERMINAL,	"-terminal",	"-noterminal",	},
 	{ OPTION_TOUCH,		"-touch",	"-notouch",	},
 	{ OPTION_UPDATE,	"-timeadjust",	"-notimeadjust", },
+	{ OPTION_TELL_POSITION,	"-tellposition", "-notellposition", },
 };
 
 
