@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2001 Peter Miller;
+ *	Copyright (C) 1994-1999, 2001, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -27,7 +27,7 @@
  * When cook has a target, cook performs the following actions in the order
  * given:
  *
- * 1.	Cook scans through the instanciated prerequisite recipes. All
+ * 1.	Cook scans through the instantiated prerequisite recipes. All
  *	prerequisite recipes with the target in their target list are used.
  *
  *	If the recipe is used, any prerequisite files are recursively
@@ -35,7 +35,7 @@
  *	all other explicit or implicit recipes with the same target will be
  *	deemed to be out of date.
  *
- * 2.	Cook then scans through the instanciated explicit recipes. All
+ * 2.	Cook then scans through the instantiated explicit recipes. All
  *	explicit recipes with the target in their target list are used.
  *
  *	If the recipe is used, any prerequisite files are recursively
@@ -49,7 +49,7 @@
  *	the recipe.
  *
  * 3.	If the target was not the subject of any explicit recipe, cook then
- *	scans the instanciated implicit recipes. Only first implicit recipe
+ *	scans the instantiated implicit recipes. Only first implicit recipe
  *	for which cook knows how to cook will be used.
  *
  *	Implicit recipe targets and prerequisites may contain a wilcard
