@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1990, 1991, 1992, 1993, 1995, 1997 Peter Miller;
+ *	Copyright (C) 1990, 1991, 1992, 1993, 1995, 1997, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -37,7 +37,8 @@ struct expr_method_ty
 	size_t	size;
 	void	(*destructor)_((struct expr_ty *));
 	int	(*equal)_((const struct expr_ty *, const struct expr_ty *));
-	void	(*code_generate)_((const struct expr_ty *, struct opcode_list_ty *));
+	void	(*code_generate)_((const struct expr_ty *,
+			struct opcode_list_ty *));
 };
 
 typedef struct expr_ty expr_ty;
@@ -51,7 +52,8 @@ struct expr_ty
 expr_ty *expr_copy _((expr_ty *));
 void expr_delete _((expr_ty *));
 int expr_eval_condition _((const expr_ty *, const struct match_ty *));
-struct string_list_ty *expr_evaluate _((const expr_ty *, const struct match_ty *));
+struct string_list_ty *expr_evaluate _((const expr_ty *,
+	const struct match_ty *));
 int expr_equal _((const expr_ty *, const expr_ty *));
 void expr_code_generate _((const expr_ty *, struct opcode_list_ty *));
 
