@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1994, 1997, 1999 Peter Miller;
+ *	Copyright (C) 1994, 1997, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -32,6 +32,10 @@ struct fp_value_ty *fp_search _((struct string_ty *path));
 void fp_assign _((struct string_ty *, struct fp_value_ty *));
 void fp_delete _((struct string_ty *));
 struct string_ty *fp_fingerprint _((struct string_ty *path));
+struct string_ty *fp_fingerprint_string _((struct string_ty *value));
 void fp_tweak _((void));
 
+int fp_ingredients_fingerprint_differs _((struct string_ty *,
+	struct string_ty *));
+
 #endif /* COOK_FNGRPRNT_H */
