@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1999 Peter Miller;
+ *	Copyright (C) 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -214,6 +214,7 @@ fp_subdir_write(this, need_to_write_dot)
 	static string_ty *dot;
 	string_ty	*fn;
 	FILE		*fp;
+	struct stat	st;
 
 	/*
 	 * If we aren't dirty, don't write us out
@@ -232,10 +233,18 @@ fp_subdir_write(this, need_to_write_dot)
 	fn = os_path_cat(this->path, fp_filename());
 
 	/*
-	 * Open the file for writing.
-	 * If there is a permissions problem, quietly slink away.
+	 * We are about to write the file.  If the file isn't a regular
+	 * file, unlink it.  (It could be part of a symlink farm, it
+	 * could be someone being naughty, it could be plain stupid.)
 	 */
-	if (unlink(fn->str_text))
+	if
+	(
+		stat(fn->str_text, &st) == 0
+	&&
+		!S_ISREG(st.st_mode)
+	&&
+		unlink(fn->str_text) != 0
+	)
 	{
 		switch (errno)
 		{
@@ -256,6 +265,10 @@ fp_subdir_write(this, need_to_write_dot)
 		}
 	}
 
+	/*
+	 * Open the file for writing.
+	 * If there is a permissions problem, quietly slink away.
+	 */
 	fp = fopen(fn->str_text, "w");
 	if (!fp)
 	{
@@ -388,7 +401,7 @@ fp_subdir_tweak(this)
 		trace(("stat(\"%s\")\n", s->str_text));
 #ifdef S_IFLNK
 		err = lstat(s->str_text, &st);
-#else  
+#else
 		err = stat(s->str_text, &st);
 #endif
 		if (err)
