@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1998, 2001 Peter Miller;
+ *	Copyright (C) 1997, 1998, 2001, 2003 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -78,11 +78,11 @@ target_new(filename)
 {
 	target_ty	*tp;
 
-	trace(("target_new()\n{\n"/*}*/));
+	trace(("target_new()\n{\n"));
 	tp = mem_alloc(sizeof(target_ty));
 	tp->filename = str_copy(filename);
 	string_list_constructor(&tp->pos);
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 	return tp;
 }
 
@@ -105,11 +105,11 @@ static void
 target_delete(tp)
 	target_ty	*tp;
 {
-	trace(("target_delete()\n{\n"/*}*/));
+	trace(("target_delete()\n{\n"));
 	str_free(tp->filename);
 	string_list_destructor(&tp->pos);
 	mem_free(tp);
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 }
 
 
@@ -157,9 +157,9 @@ target_append(tp, pp)
 	target_ty	*tp;
 	const expr_position_ty *pp;
 {
-	trace(("target_append()\n{\n"/*}*/));
+	trace(("target_append()\n{\n"));
 	string_list_append_unique(&tp->pos, pp->pos_name);
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 }
 
 
@@ -229,11 +229,11 @@ target_check(gfpp, tp, ingredient, gp)
 	 * If any of the cookbooks which describe this relationship are
 	 * leaf files, there is no problem.  Leave quietly.
 	 */
-	trace(("ingredient_new()\n{\n"/*}*/));
+	trace(("ingredient_new()\n{\n"));
 	assert(tp->pos.nstrings);
 	if (!tp->pos.nstrings)
 	{
-		trace((/*{*/"}\n"));
+		trace(("}\n"));
 		return;
 	}
 	for (j = 0; j < tp->pos.nstrings; ++j)
@@ -241,7 +241,7 @@ target_check(gfpp, tp, ingredient, gp)
 		fn = tp->pos.string[j];
 		if (!foreign_derived(gfpp, fn) && graph_file_leaf_p(gp, fn))
 		{
-			trace((/*{*/"}\n"));
+			trace(("}\n"));
 			return;
 		}
 	}
@@ -267,7 +267,7 @@ target_check(gfpp, tp, ingredient, gp)
 		the_long_version = 1;
 		error_intl(0, i18n("this means that a clean build will fail"));
 	}
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 }
 
 
@@ -297,12 +297,12 @@ ingredient_new(filename, include_cooked)
 {
 	ingredient_ty	*ip;
 
-	trace(("ingredient_new()\n{\n"/*}*/));
+	trace(("ingredient_new()\n{\n"));
 	ip = mem_alloc(sizeof(ingredient_ty));
 	ip->filename = str_copy(filename);
 	ip->include_cooked = include_cooked;
 	ip->target = 0;
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 	return ip;
 }
 
@@ -325,12 +325,12 @@ static void
 ingredient_delete(ip)
 	ingredient_ty	*ip;
 {
-	trace(("ingredient_delete()\n{\n"/*}*/));
+	trace(("ingredient_delete()\n{\n"));
 	str_free(ip->filename);
 	if (ip->target)
 		symtab_free(ip->target);
 	mem_free(ip);
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 }
 
 
@@ -384,7 +384,7 @@ ingredient_append(ip, target, pp)
 {
 	target_ty	*tp;
 
-	trace(("ingredient_append()\n{\n"/*}*/));
+	trace(("ingredient_append()\n{\n"));
 	if (!ip->target)
 	{
 		ip->target = symtab_alloc(1);
@@ -397,7 +397,7 @@ ingredient_append(ip, target, pp)
 		symtab_assign(ip->target, target, tp);
 	}
 	target_append(tp, pp);
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 }
 
 
@@ -432,12 +432,16 @@ ingredient_check(gfpp, ip, target, gp)
 	 * Find the target.  It should always be there, but if it is
 	 * not, leave quietly.
 	 */
-	trace(("ingredient_append()\n{\n"/*}*/));
+	trace(("ingredient_check()\n{\n"));
+	assert(gfpp);
+	assert(ip);
+	assert(ip->target);
+	assert(target);
 	tp = symtab_query(ip->target, target);
 	assert(tp);
 	if (!tp)
 	{
-		trace((/*{*/"}\n"));
+		trace(("}\n"));
 		return;
 	}
 
@@ -446,7 +450,7 @@ ingredient_check(gfpp, ip, target, gp)
 	 * which describe this relationship.
 	 */
 	target_check(gfpp, tp, ip->filename, gp);
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 }
 
 
@@ -472,7 +476,7 @@ graph_file_pair_new(slp)
 	graph_file_pair_ty *gfpp;
 	size_t		j;
 
-	trace(("graph_file_pair_new()\n{\n"/*}*/));
+	trace(("graph_file_pair_new()\n{\n"));
 	gfpp = mem_alloc(sizeof(graph_file_pair_ty));
 	gfpp->stp = symtab_alloc(slp ? slp->nstrings : 5);
 	gfpp->stp->reap = ingredient_reap;
@@ -487,7 +491,7 @@ graph_file_pair_new(slp)
 			symtab_assign(gfpp->stp, slp->string[j], ip);
 		}
 	}
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 	return gfpp;
 }
 
@@ -508,12 +512,12 @@ void
 graph_file_pair_delete(gfpp)
 	graph_file_pair_ty *gfpp;
 {
-	trace(("graph_file_pair_delete()\n{\n"/*}*/));
+	trace(("graph_file_pair_delete()\n{\n"));
 	symtab_free(gfpp->stp);
 	if (gfpp->foreign_derived)
 		symtab_free(gfpp->foreign_derived);
 	mem_free(gfpp);
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 }
 
 
@@ -542,7 +546,7 @@ graph_file_pair_remember(gfpp, target, ingredient, pp)
 	ingredient_ty	*ip;
 
 	trace(("graph_file_pair_remember(target = \"%s\", \
-ingredient = \"%s\")\n{\n"/*}*/,
+ingredient = \"%s\")\n{\n",
 		target->str_text, ingredient->str_text));
 	ip = symtab_query(gfpp->stp, ingredient);
 	if (!ip)
@@ -551,7 +555,7 @@ ingredient = \"%s\")\n{\n"/*}*/,
 		symtab_assign(gfpp->stp, ingredient, ip);
 	}
 	ingredient_append(ip, target, pp);
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 }
 
 
@@ -580,7 +584,7 @@ graph_file_pair_remember_tlist(gfpp, target, ingredient, pp)
 {
 	size_t		j;
 
-	trace(("graph_file_pair_remember_tlist()\n{\n"/*}*/));
+	trace(("graph_file_pair_remember_tlist()\n{\n"));
 	for (j = 0; j < target->nstrings; ++j)
 	{
 		graph_file_pair_remember
@@ -591,7 +595,7 @@ graph_file_pair_remember_tlist(gfpp, target, ingredient, pp)
 			pp
 		);
 	}
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 }
 
 
@@ -604,7 +608,7 @@ graph_file_pair_remember_lists(gfpp, target, ingredient, pp)
 {
 	size_t		k;
 
-	trace(("graph_file_pair_remember_lists()\n{\n"/*}*/));
+	trace(("graph_file_pair_remember_lists()\n{\n"));
 	for (k = 0; k < ingredient->nstrings; ++k)
 	{
 		graph_file_pair_remember_tlist
@@ -615,7 +619,7 @@ graph_file_pair_remember_lists(gfpp, target, ingredient, pp)
 			pp
 		);
 	}
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 }
 
 
@@ -646,10 +650,10 @@ graph_file_pair_check(gfpp, target, ingredient, gp)
 	 * We are looking for non-leaf ingredients.
 	 * If this ingredient is a leaf, no further processing is equired.
 	 */
-	trace(("graph_file_pair_check()\n{\n"/*}*/));
+	trace(("graph_file_pair_check()\n{\n"));
 	if (graph_file_leaf_p(gp, ingredient))
 	{
-		trace((/*{*/"}\n"));
+		trace(("}\n"));
 		return;
 	}
 
@@ -662,13 +666,13 @@ graph_file_pair_check(gfpp, target, ingredient, gp)
 	assert(ip);
 	if (!ip)
 	{
-		trace((/*{*/"}\n"));
+		trace(("}\n"));
 		return;
 	}
 	assert(ip->target);
 	if (!ip->target)
 	{
-		trace((/*{*/"}\n"));
+		trace(("}\n"));
 		return;
 	}
 
@@ -676,7 +680,7 @@ graph_file_pair_check(gfpp, target, ingredient, gp)
 	 * check back to the target via the ingredient
 	 */
 	ingredient_check(gfpp, ip, target, gp);
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 }
 
 
@@ -711,3 +715,65 @@ graph_file_pair_foreign_derived(gfpp, slp)
 		symtab_assign(gfpp->foreign_derived, fn, fn);
 	}
 }
+
+
+#ifdef DEBUG
+
+
+/*
+ * NAME
+ *	graph_file_pair_check
+ *
+ * SYNOPSIS
+ *	int graph_file_pair_exists(graph_file_pair_ty *gfpp,
+ *	    string_ty *target, string_ty *ingredient);
+ *
+ * DESCRIPTION
+ *	The graph_file_pair_exists function is used at debug time to
+ *	check that the graph file pairs have been constructed correctly.
+ */
+
+int
+graph_file_pair_exists(gfpp, target, ingredient)
+	graph_file_pair_ty *gfpp;
+	string_ty	*target;
+	string_ty	*ingredient;
+{
+	ingredient_ty	*ip;
+	int             result;
+
+	/*
+	 * We are looking for non-leaf ingredients.
+	 * If this ingredient is a leaf, no further processing is equired.
+	 */
+	trace(("graph_file_pair_exists()\n{\n"));
+	if (!gfpp)
+	{
+		trace(("return 0;\n}\n"));
+		return 0;
+	}
+
+	/*
+	 * Make sure the ingredient is known.
+	 */
+	ip = symtab_query(gfpp->stp, ingredient);
+	if (!ip)
+	{
+		trace(("return 0;\n}\n"));
+		return 0;
+	}
+
+	/*
+	 * Make sure the ingredient has heard of the target.
+	 */
+	if (!ip->target)
+	{
+		trace(("return 0;\n}\n"));
+		return 0;
+	}
+	result = !!symtab_query(ip->target, target);
+	trace(("return %d;\n}\n", result));
+	return result;
+}
+
+#endif
