@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1998, 1999, 2000, 2001 Peter Miller;
+ *	Copyright (C) 1997-2001, 2003 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,9 +25,6 @@
 #include <ac/stdio.h>
 #include <ac/stdlib.h>
 #include <ac/time.h>
-#ifdef HAVE_WAIT3
-#include <sys/resource.h>
-#endif
 #include <sys/wait.h>
 
 #include <desist.h>
@@ -46,6 +43,7 @@
 #include <id.h>
 #include <id/variable.h>
 #include <itab.h>
+#include <meter.h>
 #include <opcode/context.h>
 #include <option.h>
 #include <os/wait.h>
@@ -704,47 +702,42 @@ graph_walk_inner(gp, func, nproc)
 			 */
 			if (itp->load > 0)
 			{
-				int		pid;
-				int		exit_status;
-				struct rusage	ru;
+			    int             pid;
+			    int             exit_status;
+			    struct rusage   ru;
 
-				trace(("mark\n"));
-				pid = os_wait3(&exit_status, WNOHANG, &ru);
-				trace(("pid = %d\n", pid));
-				if (pid < 0)
-				{
-					sub_context_ty	*scp;
+			    trace(("mark\n"));
+			    pid = os_wait3(&exit_status, WNOHANG, &ru);
+			    trace(("pid = %d\n", pid));
+			    if (pid < 0)
+			    {
+				sub_context_ty  *scp;
 
-					if (errno == EINTR)
-						continue;
-					scp = sub_context_new();
-					sub_errno_set(scp);
-					fatal_intl(scp, i18n("wait(): $errno"));
-					/* NOTREACHED */
-				}
-				else if (pid > 0)
+				if (errno == EINTR)
+				    continue;
+				scp = sub_context_new();
+				sub_errno_set(scp);
+				fatal_intl(scp, i18n("wait(): $errno"));
+				/* NOTREACHED */
+			    }
+			    else if (pid > 0)
+			    {
+				trace(("es = 0x%04X\n", exit_status));
+				grp = itab_query(itp, pid);
+				if (grp)
 				{
-					trace(("es = 0x%04X\n", exit_status));
-					grp = itab_query(itp, pid);
-					if (grp)
-					{
-						/* if it's one of ours... */
-						trace(("...waited\n"));
-						assert(pid ==
-						      graph_recipe_getpid(grp));
-						if (grp->ocp->rup)
-							*(grp->ocp->rup) = ru;
-						graph_recipe_waited
-						(
-							grp,
-							exit_status
-						);
-						itab_delete(itp, pid);
-						trace(("itp->load = %ld;\n",
-							(long)itp->load));
-						goto run_a_recipe;
-					}
+				    /* if it's one of ours... */
+				    trace(("...waited\n"));
+				    assert(pid == graph_recipe_getpid(grp));
+				    if (grp->ocp->meter_p)
+					grp->ocp->meter_p->ru = ru;
+				    graph_recipe_waited(grp, exit_status);
+				    itab_delete(itp, pid);
+				    trace(("itp->load = %ld;\n",
+					(long)itp->load));
+				    goto run_a_recipe;
 				}
+			    }
 			}
 #endif /* HAVE_WAIT3 */
 		}
@@ -790,8 +783,8 @@ graph_walk_inner(gp, func, nproc)
 				trace(("...waited\n"));
 				assert(pid == graph_recipe_getpid(grp));
 #ifdef HAVE_WAIT3
-				if (grp->ocp->rup)
-					*(grp->ocp->rup) = ru;
+				if (grp->ocp->meter_p)
+					grp->ocp->meter_p->ru = ru;
 #endif
 				graph_recipe_waited(grp, exit_status);
 				itab_delete(itp, pid);
