@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1999 Peter Miller;
+ *	Copyright (C) 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -86,7 +86,7 @@ graph_recipe_web(grp)
 	assert(grp->output);
 	assert(grp->output->nfiles > 0);
 	if (grp->output->nfiles > 0)
-		string_list_append(&wl, grp->output->file[0]->filename);
+		string_list_append(&wl, grp->output->item[0].file->filename);
 	opcode_context_id_assign(grp->ocp, id_target, id_variable_new(&wl), -1);
 	string_list_destructor(&wl);
 
@@ -96,8 +96,14 @@ graph_recipe_web(grp)
 	string_list_constructor(&wl);
 	assert(grp->input);
 	for (j = 0; j < grp->output->nfiles; ++j)
-		string_list_append(&wl, grp->output->file[j]->filename);
-	opcode_context_id_assign(grp->ocp, id_targets, id_variable_new(&wl), -1);
+		string_list_append(&wl, grp->output->item[j].file->filename);
+	opcode_context_id_assign
+	(
+		grp->ocp,
+		id_targets,
+		id_variable_new(&wl),
+		-1
+	);
 	string_list_destructor(&wl);
 
 	/*
@@ -107,9 +113,15 @@ graph_recipe_web(grp)
 	string_list_constructor(&wl);
 	assert(grp->input);
 	for (j = 0; j < grp->input->nfiles; ++j)
-		string_list_append(&wl, grp->input->file[j]->filename);
+		string_list_append(&wl, grp->input->item[j].file->filename);
 	opcode_context_id_assign(grp->ocp, id_need, id_variable_new(&wl), -1);
-	opcode_context_id_assign(grp->ocp, id_younger, id_variable_new(&wl), -1);
+	opcode_context_id_assign
+	(
+		grp->ocp,
+		id_younger,
+		id_variable_new(&wl),
+		-1
+	);
 	string_list_destructor(&wl);
 
 	/*
@@ -154,8 +166,8 @@ graph_recipe_web(grp)
 	 */
 	printf("<dt>Target%s:<dd>\n", (grp->output->nfiles==1?"":"s"));
 	for (j = 0; j < grp->output->nfiles; ++j)
-	{ 
-		s = grp->output->file[j]->filename;
+	{
+		s = grp->output->item[j].file->filename;
 		printf
 		(
 			"<tt><a href=\"#%s\">%s</a></tt>,\n",
@@ -170,7 +182,7 @@ graph_recipe_web(grp)
 	printf("<dt>Ingredient%s:<dd>\n", (grp->input->nfiles==1?"":"s"));
 	for (j = 0; j < grp->input->nfiles; ++j)
 	{
-		s = grp->input->file[j]->filename;
+		s = grp->input->item[j].file->filename;
 		printf
 		(
 			"<tt><a href=\"#%s\">%s</a></tt>,\n",
@@ -215,13 +227,19 @@ graph_recipe_web(grp)
 			{
 				graph_file_ty	*gfp;
 
-				gfp = grp->output->file[j];
+				gfp = grp->output->item[j].file;
 				s = dir_part(gfp->filename);
 				if (!s)
 					continue;
 				printf("if test ! -d %s; then\n", s->str_text);
 				if (echo)
-					printf("echo mkdir -p %s\n", s->str_text);
+				{
+					printf
+					(
+						"echo mkdir -p %s\n",
+						s->str_text
+					);
+				}
 				printf("mkdir -p %s", s->str_text);
 				if (!option_test(OPTION_ERROK))
 					printf(" || exit 1");
@@ -235,7 +253,7 @@ graph_recipe_web(grp)
 			{
 				graph_file_ty	*gfp;
 
-				gfp = grp->output->file[j];
+				gfp = grp->output->item[j].file;
 				s = gfp->filename;
 				if (echo)
 					printf("echo rm %s\n", s->str_text);
@@ -251,7 +269,7 @@ graph_recipe_web(grp)
 			{
 				graph_file_ty	*gfp;
 
-				gfp = grp->output->file[j];
+				gfp = grp->output->item[j].file;
 				s = gfp->filename;
 				if (echo)
 					printf("echo touch %s\n", s->str_text);
@@ -332,7 +350,7 @@ graph_file_web(gfp)
 			printf("Recipe Instance %d</a>", grp->id);
 			if (grp->input->nfiles > 0)
 			{
-				gfp2 = grp->input->file[0];
+				gfp2 = grp->input->item[0].file;
 				printf
 				(
 					" (<a href=\"#%s\">%s</a>%s)",
@@ -355,13 +373,13 @@ graph_file_web(gfp)
 			printf("Recipe Instance %d</a>", grp->id);
 			if (grp->output->nfiles > 0)
 			{
-				gfp2 = grp->output->file[0];
+				gfp2 = grp->output->item[0].file;
 				printf
 				(
 					" (<a href=\"#%s\">%s</a>%s)",
 					gfp2->filename->str_text,
 					gfp2->filename->str_text,
-					(grp->output->nfiles >= 2 ? ", ..." : "")
+				       (grp->output->nfiles >= 2 ? ", ..." : "")
 				);
 			}
 			printf(",\n");
@@ -386,7 +404,7 @@ web_file_stash(stp, key, data, aux)
 
 	gfp = data;
 	gflp = aux;
-	graph_file_list_nrc_append(gflp, gfp);
+	graph_file_list_nrc_append(gflp, gfp, edge_type_default);
 }
 
 
@@ -397,12 +415,12 @@ web_file_cmp(va, vb)
 	const void	*va;
 	const void	*vb;
 {
-	graph_file_ty	*a;
-	graph_file_ty	*b;
-	
-	a = *(graph_file_ty **)va;
-	b = *(graph_file_ty **)vb;
-	return strcmp(a->filename->str_text, b->filename->str_text);
+	graph_file_and_type_ty *a;
+	graph_file_and_type_ty *b;
+
+	a = (graph_file_and_type_ty *)va;
+	b = (graph_file_and_type_ty *)vb;
+	return strcmp(a->file->filename->str_text, b->file->filename->str_text);
 }
 
 
@@ -415,7 +433,7 @@ web_recipe_cmp(va, vb)
 {
 	graph_recipe_ty	*a;
 	graph_recipe_ty	*b;
-	
+
 	a = *(graph_recipe_ty **)va;
 	b = *(graph_recipe_ty **)vb;
 	return (a->id - b->id);
@@ -438,7 +456,7 @@ graph_walk_web(gp)
 	trace(("graph_walk_web(gp = %08lX)\n{\n", (long)gp));
 	graph_file_list_nrc_constructor(&gfl);
 	symtab_walk(gp->already, web_file_stash, &gfl);
-	qsort(gfl.file, gfl.nfiles, sizeof(gfl.file[0]), web_file_cmp);
+	qsort(gfl.item, gfl.nfiles, sizeof(gfl.item[0]), web_file_cmp);
 
 	/*
 	 * Fetch the list of recipe instances, and sort it by ID.
@@ -469,7 +487,7 @@ graph_walk_web(gp)
 	printf("<h2>Files</h2>\n");
 	for (j = 0; j < gfl.nfiles; ++j)
 	{
-		gfp = gfl.file[j];
+		gfp = gfl.item[j].file;
 		graph_file_web(gfp);
 	}
 
