@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997 Peter Miller;
+ *	Copyright (C) 1997, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,12 +25,8 @@
 
 #include <main.h>
 
-struct string_list_ty; /* existence */
-struct expr_position_ty; /* existence */
-struct opcode_context_ty; /* existence */
+struct builtin_ty; /* existence */
 
-struct id_ty *id_builtin_new _((int (*)(struct string_list_ty *,
-	const struct string_list_ty *, const struct expr_position_ty *,
-	const struct opcode_context_ty *)));
+struct id_ty *id_builtin_new _((builtin_ty *));
 
 #endif /* COOK_ID_BUILTIN_H */
