@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1993, 1994, 1995, 1997, 1998, 1999, 2001 Peter Miller;
+ *	Copyright (C) 1993-1995, 1997-1999, 2001, 2003 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -70,6 +70,44 @@
 #define UNQUOTED_WORD 32767
 #define EOLN 32766
 
+enum internal_token_ty
+{
+    internal_token_eof,
+    internal_token_eoln,
+    internal_token_word,
+    internal_token_unquoted_word,
+    internal_token_data,
+    internal_token_dataend,
+    internal_token_catenate,
+    internal_token_file_boundary,
+};
+typedef enum internal_token_ty internal_token_ty;
+
+
+#ifdef DEBUG
+
+static const char *
+internal_token_name(internal_token_ty tok)
+{
+    static char buffer[16];
+
+    switch (tok)
+    {
+    case internal_token_eof: return "internal_token_eof";
+    case internal_token_eoln: return "internal_token_eoln";
+    case internal_token_word: return "internal_token_word";
+    case internal_token_unquoted_word: return "internal_token_unquoted_word";
+    case internal_token_data: return "internal_token_data";
+    case internal_token_dataend: return "internal_token_dataend";
+    case internal_token_catenate: return "internal_token_catenate";
+    case internal_token_file_boundary: return "internal_token_file_boundary";
+    }
+    sprintf(buffer, "%d", tok);
+    return buffer;
+}
+
+#endif
+
 
 typedef struct meta_ty meta_ty;
 struct meta_ty
@@ -95,7 +133,7 @@ struct lex_ty
 static	lex_ty		*root;		/* root of insert list		*/
 static	stracc		saroot;		/* root of string accum list	*/
 static	int		errcnt;		/* count of errors to date	*/
-static	int		mode;		/* what lex mode we are in	*/
+static	lex_mode_ty	mode;		/* what lex mode we are in	*/
 static	int		state;
 static	int		passing;
 static	int		catted;
@@ -170,12 +208,12 @@ lex_initialize()
 	};
 	static keyword_ty hash_keyword[] =
 	{
-		{ "[",			LBRAK,			},
-		{ "]",			RBRAK,			},
+		{ "[",			HASHLINE_LBRAK,		},
+		{ "]",			HASHLINE_RBRAK,		},
 	};
 	keyword_ty	*kp;
 
-	trace(("init_reserved()\n{\n"/*}*/));
+	trace(("init_reserved()\n{\n"));
 	passing = 1;
 
 	if (!parse_symtab)
@@ -210,7 +248,7 @@ lex_initialize()
 		symtab_assign(hash_directive_symtab, s, &kp->k_token);
 		str_free(s);
 	}
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 }
 
 
@@ -236,7 +274,7 @@ lex_open(logical, physical)
 {
 	lex_ty		*new;
 
-	trace(("lex_open(filename = %08lX)\n{\n"/*}*/, logical));
+	trace(("lex_open(filename = %08lX)\n{\n", logical));
 	trace_string(logical->str_text);
 	if (!physical)
 		physical = logical;
@@ -264,7 +302,7 @@ lex_open(logical, physical)
 	lex_filename_list_constructor(&new->pending_include_list);
 	new->have_said_eof_token = 0;
 	root = new;
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 }
 
 
@@ -301,7 +339,7 @@ lex_close()
 {
 	lex_ty		*old;
 
-	trace(("lex_close()\n{\n"/*}*/));
+	trace(("lex_close()\n{\n"));
 	assert(root);
 	old = root;
 	input_delete(root->l_file);
@@ -320,7 +358,7 @@ lex_close()
 	lex_filename_destructor(&old->filename);
 	lex_filename_list_destructor(&old->pending_include_list);
 	free(old);
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 }
 
 
@@ -372,14 +410,14 @@ byte()
 {
 	int		c;
 
-	trace(("byte()\n{\n"/*}*/));
+	trace(("byte()\n{\n"));
 	for (;;)
 	{
 		/*
 		 * leap into include file if possible
 		 */
 		assert(root);
-		if (root->pending_include_list.length)
+		while (root->pending_include_list.length)
 		{
 			lex_filename_ty	*fnp;
 
@@ -403,7 +441,16 @@ byte()
 			break;
 		lex_close();
 	}
-	if (!isprint(c) && c != EOF && !strchr("\t\n\f", c))
+	if
+	(
+	    mode != LM_COMMENT
+	&&
+	    !isprint(c)
+	&&
+	    c != EOF
+	&&
+	    !strchr("\t\n\f", c)
+	)
 	{
 		sub_context_ty	*scp;
 
@@ -427,7 +474,7 @@ byte()
 	}
 	trace_short(root->l_bol);
 	trace(("return '%c';\n", c));
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 	return c;
 }
 
@@ -452,7 +499,7 @@ static void
 byte_undo(c)
 	int		c;
 {
-	trace(("byte_undo(c = '%c')\n{\n"/*}*/, c));
+	trace(("byte_undo(c = '%c')\n{\n", c));
 	assert(root);
 	switch (c)
 	{
@@ -467,7 +514,7 @@ byte_undo(c)
 		input_ungetc(root->l_file, c);
 		break;
 	}
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 }
 
 
@@ -580,7 +627,7 @@ static void
 meta(val)
 	meta_ty		*val;
 {
-	trace(("meta(val = %08lX)\n{\n"/*}*/, val));
+	trace(("meta(val = %08lX)\n{\n", val));
 	assert(root);
 	if (root->l_mback.m_type)
 	{
@@ -605,26 +652,31 @@ meta(val)
 			/*
 			 * processing for += token
 			 */
+			val->m_type = NORMAL;
+			val->m_flag = BEFORE | AFTER;
 			switch (mode)
 			{
 				int	c;
 
-			default:
+			case LM_NORMAL:
 				c = byte();
 				byte_undo(c);
 				if (c == '=')
 				{
 					val->m_type = NORMAL;
 					val->m_flag = SINGLE;
-					break;
 				}
-				/* fall through... */
+				break;
 
 			case LM_DATA:
 			case LM_SQUOTE:
 			case LM_DQUOTE:
-				val->m_type = NORMAL;
-				val->m_flag = BEFORE | AFTER;
+			case LM_COMMENT:
+				/*
+				 * I haven't used "default:" so that
+				 * GCC will barf if a new mode is added,
+				 * but not handled by this switch.
+				 */
 				break;
 			}
 			break;
@@ -632,50 +684,69 @@ meta(val)
 		case '=':
 		case ';':
 		case ':':
-		case '{'/*}*/:
-		case /*{*/'}':
+		case '{':
+		case '}':
+			val->m_type = NORMAL;
+			val->m_flag = BEFORE | AFTER;
 			switch (mode)
 			{
-			default:
-				val->m_type = NORMAL;
+			case LM_NORMAL:
 				val->m_flag = SINGLE;
 				break;
 
 			case LM_DATA:
 			case LM_SQUOTE:
 			case LM_DQUOTE:
-				val->m_type = NORMAL;
-				val->m_flag = BEFORE | AFTER;
+			case LM_COMMENT:
+				/*
+				 * I haven't used "default:" so that
+				 * GCC will barf if a new mode is added,
+				 * but not handled by this switch.
+				 */
 				break;
 			}
 			break;
 
-		case '['/*]*/:
+		case '[':
+			val->m_type = NORMAL;
+			val->m_flag = BEFORE | AFTER;
 			switch (mode)
 			{
-			default:
+			case LM_NORMAL:
+			case LM_DATA:
 				val->m_flag = BEFORE | SINGLE;
 				break;
 
 			case LM_SQUOTE:
 			case LM_DQUOTE:
-				val->m_flag = BEFORE | AFTER;
-			}
-			val->m_type = NORMAL;
+			case LM_COMMENT:
+				/*
+				 * I haven't used "default:" so that
+				 * GCC will barf if a new mode is added,
+				 * but not handled by this switch.
+				 */
 				break;
+			}
+			break;
 
-		case /*[*/']':
+		case ']':
 			val->m_type = NORMAL;
+			val->m_flag = BEFORE | AFTER;
 			switch (mode)
 			{
-			default:
+			case LM_NORMAL:
 				val->m_flag = AFTER | SINGLE;
 				break;
 
 			case LM_DATA:
 			case LM_SQUOTE:
 			case LM_DQUOTE:
-				val->m_flag = BEFORE | AFTER;
+			case LM_COMMENT:
+				/*
+				 * I haven't used "default:" so that
+				 * GCC will barf if a new mode is added,
+				 * but not handled by this switch.
+				 */
 				break;
 			}
 			break;
@@ -684,9 +755,11 @@ meta(val)
 		case '\t':
 		case '\n':
 		case '\f':
+			val->m_type = NORMAL;
+			val->m_flag = BEFORE | AFTER;
 			switch (mode)
 			{
-			default:
+			case LM_NORMAL:
 				val->m_type = WHITE;
 				val->m_flag = SINGLE;
 				break;
@@ -694,8 +767,12 @@ meta(val)
 			case LM_SQUOTE:
 			case LM_DQUOTE:
 			case LM_DATA:
-				val->m_type = NORMAL;
-				val->m_flag = BEFORE | AFTER;
+			case LM_COMMENT:
+				/*
+				 * I haven't used "default:" so that
+				 * GCC will barf if a new mode is added,
+				 * but not handled by this switch.
+				 */
 				break;
 			}
 			break;
@@ -762,9 +839,11 @@ meta(val)
 			break;
 
 		case '/':
+			val->m_type = NORMAL;
+			val->m_flag = BEFORE | AFTER;
                         switch (mode)
                         {
-                        default:
+                        case LM_NORMAL:
                             {
                                 int     c;
                                 int     gate;
@@ -779,6 +858,7 @@ meta(val)
                                 }
                                 gate = 0;
                                 count = 1;
+				mode = LM_COMMENT;
                                 while (count)
                                 {
                                     switch (c = byte())
@@ -819,6 +899,7 @@ meta(val)
                                         break;
                                     }
                                 }
+				mode = LM_NORMAL;
                                 val->m_char = ' ';
                                 val->m_type = WHITE;
                                 val->m_flag = SINGLE;
@@ -828,15 +909,19 @@ meta(val)
                         case LM_DATA:
                         case LM_SQUOTE:
                         case LM_DQUOTE:
-                            val->m_type = NORMAL;
-                            val->m_flag = BEFORE | AFTER;
+                        case LM_COMMENT:
+			    /*
+			     * I haven't used "default:" so that
+			     * GCC will barf if a new mode is added,
+			     * but not handled by this switch.
+			     */
                             break;
                         }
                         break;
 		}
 	}
 	trace(("*val = %s;\n", meta_repn(val)));
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 }
 
 
@@ -981,11 +1066,11 @@ lex_warning(scp, s)
  *	Use the #define's in lex.h.
  */
 
-int
+lex_mode_ty
 lex_mode(n)
-	int		n;
+	lex_mode_ty	n;
 {
-	int		old;
+	lex_mode_ty	old;
 
 	old = mode;
 	mode = n;
@@ -1047,11 +1132,11 @@ lex_trace(s sva_last)
 }
 
 
-static char *mode_repn _((int));
+static char *mode_repn _((lex_mode_ty));
 
 static char *
 mode_repn(n)
-	int	n;
+	lex_mode_ty	n;
 {
 	static char *name[] =
 	{
@@ -1059,6 +1144,7 @@ mode_repn(n)
 		"DATA",
 		"SQUOTE",
 		"DQUOTE",
+		"COMMENT",
 	};
 	static char buffer[12];
 
@@ -1086,21 +1172,21 @@ mode_repn(n)
  *	Lex_open must have been called previously.
  */
 
-static int tokenize _((void));
+static internal_token_ty tokenize _((void));
 
-static int
+static internal_token_ty
 tokenize()
 {
 	meta_ty		c;
-	int		tok;
+	internal_token_ty tok;
 	static meta_ty	last;
 	static int	dataended;
 
-	trace(("tokenize()\n{\n"/*}*/));
+	trace(("tokenize()\n{\n"));
 	if (dataended)
 	{
 		dataended = 0;
-		tok = DATAEND;
+		tok = internal_token_dataend;
 		goto ret;
 	}
 
@@ -1116,7 +1202,7 @@ tokenize()
 		if (c.m_flag & BEFORE)
 		{
 			catted = 1;
-			tok = CATENATE;
+			tok = internal_token_catenate;
 			goto ret;
 		}
 	}
@@ -1152,11 +1238,11 @@ tokenize()
 		case EOF:
 			if (!root->have_said_eof_token)
 			{
-				tok = FILE_BOUNDARY;
+				tok = internal_token_file_boundary;
 				root->have_said_eof_token = 1;
 			}
 			else
-				tok = 0; /* by definition of yacc */
+				tok = internal_token_eof;
 			goto ret;
 
 		case NORMAL:
@@ -1173,7 +1259,7 @@ tokenize()
 					sa_char(&saroot, ':');
 					parse_lval.lv_word = sa_close(&saroot);
 					state = 1;
-					tok = UNQUOTED_WORD;
+					tok = internal_token_unquoted_word;
 					last = c;
 					goto ret;
 				}
@@ -1193,7 +1279,7 @@ tokenize()
 					sa_char(&saroot, '=');
 					parse_lval.lv_word = sa_close(&saroot);
 					state = 1;
-					tok = UNQUOTED_WORD;
+					tok = internal_token_unquoted_word;
 					last = c;
 					goto ret;
 				}
@@ -1264,8 +1350,8 @@ tokenize()
 					    state = 0;
 					    /* don't CAT after this */
 					    last.m_flag = 0;
-					    dataended = DATAEND;
-					    tok = WORD;
+					    dataended = internal_token_dataend;
+					    tok = internal_token_word;
 					    goto ret;
 
 					case 11:
@@ -1445,9 +1531,9 @@ tokenize()
 			    }
 			    parse_lval.lv_word = sa_close(&saroot);
 			    if (sloshed)
-				tok = WORD;
+				tok = internal_token_word;
 			    else
-				tok = UNQUOTED_WORD;
+				tok = internal_token_unquoted_word;
 			}
 			goto ret;
 
@@ -1456,7 +1542,7 @@ tokenize()
 			{
 				last = c;
 				state = 0;
-				tok = EOLN;
+				tok = internal_token_eoln;
 				goto ret;
 			}
 			state = 1;
@@ -1473,8 +1559,8 @@ tokenize()
 		state,
 		mode_repn(mode)
 	));
-	trace(("return %d;\n", tok));
-	trace((/*{*/"}\n"));
+	trace(("return %s;\n", internal_token_name(tok)));
+	trace(("}\n"));
 	return tok;
 }
 
@@ -1534,48 +1620,59 @@ lex_cur_line()
 int
 parse_lex()
 {
-	int		tok;
+	internal_token_ty tok;
 	int		*data;
+	int		result;
 
-	trace(("parse_lex()\n{\n"/*}*/));
+	trace(("parse_lex()\n{\n"));
+	result = JUNK;
 	for (;;)
 	{
 		tok = tokenize();
 		if (!passing)
 		{
-			if (!tok)
+			if (tok == internal_token_eof)
 			{
 				lex_error(0, i18n("unterminated conditional"));
 				break;
 			}
-			if (tok == WORD || tok == UNQUOTED_WORD)
+			if
+			(
+				tok == internal_token_word
+			||
+				tok == internal_token_unquoted_word
+			)
 				str_free(parse_lval.lv_word);
 			continue;
 		}
 		switch (tok)
 		{
-		case EOLN:
+		case internal_token_eof:
+			result = 0;
+			break;
+
+		case internal_token_eoln:
 			continue;
 
-		case UNQUOTED_WORD:
+		case internal_token_unquoted_word:
 			assert(parse_symtab);
 			data = symtab_query(parse_symtab, parse_lval.lv_word);
 			if (data)
 			{
-				tok = *data;
+				result = *data;
 				str_free(parse_lval.lv_word);
 				parse_lval.lv_word = 0;
-				if (tok == COLON || tok == COLON2)
+				if (result == COLON || result == COLON2)
 				{
 					parse_lval.lv_position.pos_name =
 					       str_copy(root->filename.logical);
 					parse_lval.lv_position.pos_line =
 						root->l_line;
 					parse_lval.lv_position.multi =
-						(tok == COLON2);
-					tok = COLON;
+						(result == COLON2);
+					result = COLON;
 				}
-				else if (tok == SEMICOLON)
+				else if (result == SEMICOLON)
 				{
 					parse_lval.lv_position.pos_name =
 					       str_copy(root->filename.logical);
@@ -1583,9 +1680,9 @@ parse_lex()
 						root->l_line;
 					parse_lval.lv_position.multi = 0;
 				}
-				else if (tok == DATA)
+				else if (result == DATA)
 				{
-					int	winged;
+					int	whinged;
 					meta_ty	last;
 					meta_ty	c;
 
@@ -1594,7 +1691,7 @@ parse_lex()
 					 * of the line before he starts sucking
 					 * in the program data.
 					 */
-					winged = 0;
+					whinged = 0;
 					for (;;)
 					{
 						meta(&c);
@@ -1614,14 +1711,14 @@ parse_lex()
 
 						case NORMAL:
 						case SLOSHED:
-							if (!winged)
+							if (!whinged)
 							{
 								lex_error
 								(
 									0,
 			 i18n("the 'data' keyword must be the last on the line")
 								);
-								winged = 1;
+								whinged = 1;
 							}
 							continue;
 
@@ -1637,14 +1734,34 @@ parse_lex()
 				}
 			}
 			else
-				tok = WORD;
+				result = WORD;
+			break;
+
+		case internal_token_word:
+			result = WORD;
+			break;
+
+		case internal_token_data:
+			result = DATA;
+			break;
+
+		case internal_token_dataend:
+			result = DATAEND;
+			break;
+
+		case internal_token_catenate:
+			result = CATENATE;
+			break;
+
+		case internal_token_file_boundary:
+			result = FILE_BOUNDARY;
 			break;
 		}
 		break;
 	}
 	trace(("return %d;\n", tok));
-	trace((/*{*/"}\n"));
-	return tok;
+	trace(("}\n"));
+	return result;
 }
 
 
@@ -1671,40 +1788,50 @@ static int hashline_lex_nwords;
 int
 hashline_lex()
 {
-	int		tok;
+	internal_token_ty tok;
 	int		*data;
 	string_ty	*guess;
 	sub_context_ty	*scp;
+	int		result;
 
-	trace(("hashline_lex()\n{\n"/*}*/));
+	trace(("hashline_lex()\n{\n"));
 	tok = tokenize();
+	result = HASH_JUNK;
+	hashline_lval.lv_word = parse_lval.lv_word;
+	parse_lval.lv_word = 0;
 	switch (tok)
 	{
-	case EOLN:
-		tok = 0;
+	case internal_token_eoln:
+	case internal_token_eof:
+		result = 0;
 		break;
 
-	case UNQUOTED_WORD:
+	case internal_token_unquoted_word:
 		assert(hash_symtab);
 		if (hashline_lex_nwords)
 		{
-			data = symtab_query(hash_symtab, parse_lval.lv_word);
+			data = symtab_query(hash_symtab, hashline_lval.lv_word);
 			if (data)
 			{
-				tok = *data;
-				str_free(parse_lval.lv_word);
-				parse_lval.lv_word = 0;
+				result = *data;
+				str_free(hashline_lval.lv_word);
+				hashline_lval.lv_word = 0;
 			}
 			else
-				tok = WORD;
+				result = HASHLINE_WORD;
 			break;
 		}
-		data = symtab_query(hash_directive_symtab, parse_lval.lv_word);
+		data =
+			symtab_query
+			(
+				hash_directive_symtab,
+				hashline_lval.lv_word
+			);
 		if (data)
 		{
-			tok = *data;
-			str_free(parse_lval.lv_word);
-			parse_lval.lv_word = 0;
+			result = *data;
+			str_free(hashline_lval.lv_word);
+			hashline_lval.lv_word = 0;
 			break;
 		}
 		guess = 0;
@@ -1712,14 +1839,14 @@ hashline_lex()
 			symtab_query_fuzzy
 			(
 				hash_directive_symtab,
-				parse_lval.lv_word,
+				hashline_lval.lv_word,
 				&guess
 			);
 		if (data)
 		{
 			scp = sub_context_new();
 			assert(guess);
-			sub_var_set(scp, "Name", "%S", parse_lval.lv_word);
+			sub_var_set(scp, "Name", "%S", hashline_lval.lv_word);
 			sub_var_set(scp, "Guess", "%S", guess);
 			lex_error
 			(
@@ -1727,27 +1854,39 @@ hashline_lex()
 				i18n("unknown #$name directive, guess #$guess")
 			);
 			sub_context_delete(scp);
-			tok = *data;
+			result = *data;
 			/* DO NOT str_free guess */
-			str_free(parse_lval.lv_word);
-			parse_lval.lv_word = 0;
+			str_free(hashline_lval.lv_word);
+			hashline_lval.lv_word = 0;
 			break;
 		}
 		scp = sub_context_new();
-		sub_var_set(scp, "Name", "%S", parse_lval.lv_word);
+		sub_var_set(scp, "Name", "%S", hashline_lval.lv_word);
 		lex_error(scp, i18n("unknown #$name directive"));
 		sub_context_delete(scp);
-		str_free(parse_lval.lv_word);
-		parse_lval.lv_word = 0;
-		tok = HASH_JUNK;
+		str_free(hashline_lval.lv_word);
+		hashline_lval.lv_word = 0;
+		result = HASH_JUNK;
+		break;
+
+	case internal_token_word:
+		result = HASHLINE_WORD;
+		break;
+
+	case internal_token_data:
+	case internal_token_dataend:
+	case internal_token_file_boundary:
+		result = HASH_JUNK;
+		break;
+
+	case internal_token_catenate:
+		result = HASHLINE_CATENATE;
 		break;
 	}
 	++hashline_lex_nwords;
-	assert(sizeof(hashline_lval) == sizeof(parse_lval));
-	memcpy(&hashline_lval, &parse_lval, sizeof(hashline_lval));
-	trace(("return %d;\n", tok));
-	trace((/*{*/"}\n"));
-	return tok;
+	trace(("return %d;\n", result));
+	trace(("}\n"));
+	return result;
 }
 
 
