@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1999, 2000 Peter Miller;
+ *	Copyright (C) 1999, 2000, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -297,7 +297,8 @@ constructor(mp)
  *	attempt - match pattern to string
  *
  * SYNOPSIS
- *	int attempt(char *original_patn, char *patn, char *str, match_ty *field);
+ *	int attempt(char *original_patn, char *patn, char *str,
+ *		match_ty *field);
  *
  * DESCRIPTION
  *	The attempt function is used to match up a pattern with a string,
@@ -393,8 +394,10 @@ actual_begin = %08lX)\n{\n",
 		--formal_end;
 		--actual_end;
 	}
-	trace(("formal = \"%.*s\";\n", (int)(formal_end - formal_begin), formal_begin));
-	trace(("actual = \"%.*s\";\n", (int)(actual_end - actual_begin), actual_begin));
+	trace(("formal = \"%.*s\";\n",
+		(int)(formal_end - formal_begin), formal_begin));
+	trace(("actual = \"%.*s\";\n",
+		(int)(actual_end - actual_begin), actual_begin));
 
 	for (;;)
 	{
@@ -473,7 +476,11 @@ actual_begin = %08lX)\n{\n",
 			if
 			(
 				(
-					formal_begin > this->formal->str_text + 2
+					(
+						formal_begin
+					>
+						this->formal->str_text + 2
+					)
 				&&
 					formal_begin[-3] != '/'
 				)
@@ -501,9 +508,22 @@ actual_begin = %08lX)\n{\n",
 			{
 				if
 				(
-					actual_begin + sp->str_length > actual_end
+					(
+						actual_begin + sp->str_length
+					>
+						actual_end
+					)
 				||
-					0 != memcmp(actual_begin, sp->str_text, sp->str_length)
+					(
+						0
+					!=
+						memcmp
+						(
+							actual_begin,
+							sp->str_text,
+							sp->str_length
+						)
+					)
 				)
 				{
 					result = 0;
@@ -525,9 +545,13 @@ actual_begin = %08lX)\n{\n",
 						break;
 					--midpoint;
 				}
-			
+
 				this->fill[0] =
-					str_n_from_c(actual_begin, midpoint - actual_begin);
+					str_n_from_c
+					(
+						actual_begin,
+						midpoint - actual_begin
+					);
 				trace_string(this->fill[0]->str_text);
 				sub_result =
 					attempt_inner
@@ -586,7 +610,16 @@ actual_begin = %08lX)\n{\n",
 			(
 				actual_begin + sp->str_length > actual_end
 			||
-				0 != memcmp(actual_begin, sp->str_text, sp->str_length)
+				(
+					0
+				!=
+					memcmp
+					(
+						actual_begin,
+						sp->str_text,
+						sp->str_length
+					)
+				)
 			)
 			{
 				result = 0;
@@ -602,13 +635,25 @@ actual_begin = %08lX)\n{\n",
 		 */
 		if (formal_begin >= formal_end)
 		{
-			if (memchr(actual_begin, '/', actual_end - actual_begin))
+			if
+			(
+				memchr
+				(
+					actual_begin,
+					'/',
+					actual_end - actual_begin
+				)
+			)
 			{
 				result = 0;
 				goto ret;
 			}
 			this->fill[idx] =
-				str_n_from_c(actual_begin, actual_end - actual_begin);
+				str_n_from_c
+				(
+					actual_begin,
+					actual_end - actual_begin
+				);
 			trace(("idx = %ld;\n", (long)idx));
 			result = 1;
 			break;
@@ -626,7 +671,12 @@ actual_begin = %08lX)\n{\n",
 			(
 				formal_begin < formal_end
 			&&
-				!memchr(formal_begin, '/', formal_end - formal_begin)
+				!memchr
+				(
+					formal_begin,
+					'/',
+					formal_end - formal_begin
+				)
 			)
 			{
 				result = 0;
