@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1998, 1999, 2000, 2001 Peter Miller;
+ *	Copyright (C) 1997-2001, 2003 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -31,6 +31,7 @@
 #include <id/variable.h>
 #include <match/stack.h>
 #include <mem.h>
+#include <meter.h>
 #include <opcode.h>
 #include <opcode/context.h>
 #include <opcode/list.h>
@@ -81,7 +82,7 @@ opcode_context_new(olp, mp)
 	ocp->msp = 0;
 	ocp->pid = 0;
 	ocp->exit_status = 0;
-	ocp->rup = 0;
+	ocp->meter_p = 0;
 	ocp->wlp = 0;
 	ocp->need_age = 0;
 	ocp->flags = 0;
@@ -132,8 +133,8 @@ opcode_context_delete(ocp)
 	ocp->value_stack_length = 0;
 	ocp->value_stack_maximum = 0;
 	ocp->value_stack = 0;
-	if (ocp->rup)
-		mem_free(ocp->rup);
+	if (ocp->meter_p)
+		meter_free(ocp->meter_p);
 	if (ocp->thread_stp)
 		symtab_free(ocp->thread_stp);
 	if (ocp->msp)
