@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997 Peter Miller;
+ *	Copyright (C) 1997, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -33,8 +33,10 @@ struct opcode_method_ty
 	char		*name;
 	int		size;
 	void		(*destructor)_((opcode_ty *));
-	opcode_status_ty (*execute)_((const opcode_ty *, struct opcode_context_ty *));
-	opcode_status_ty (*script)_((const opcode_ty *, struct opcode_context_ty *));
+	opcode_status_ty (*execute)_((const opcode_ty *,
+				struct opcode_context_ty *));
+	opcode_status_ty (*script)_((const opcode_ty *,
+				struct opcode_context_ty *));
 	void		(*disassemble)_((const opcode_ty *));
 };
 
