@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1999 Peter Miller;
+ *	Copyright (C) 1997, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -27,7 +27,6 @@
 #include <match.h>
 #include <opcode/private.h>
 #include <opcode/string.h>
-#include <quote.h>
 #include <str.h>
 #include <trace.h>
 
@@ -150,7 +149,7 @@ disassemble(op)
 
 	trace(("opcode_string::disassemle()\n{\n"/*}*/));
 	this = (const opcode_string_ty *)op;
-	s = quoted(this->value);
+	s = str_quote_cook(this->value, '"');
 	printf("%s", s->str_text);
 	str_free(s);
 	trace((/*{*/"}\n"));
