@@ -20,7 +20,7 @@
  * MANIFEST: functions to manipulate rel_if_posss
  */
 
-#include <os.h>
+#include <os_interface.h>
 #include <os/below_dir.h>
 #include <os/rel_if_poss.h>
 
