@@ -145,7 +145,17 @@ stat_cache_fingerprint(path, cp)
 	{
 	    string_ty	    *s;
 	    fp_value_ty	    data;
-	    time_t	    now;
+	    static time_t    now;
+
+	    /*
+	     * It is important to use the same concept of "now" for
+	     * all file time adjustments.  That way, when both a target
+	     * and an ingredient change at the some time (yes, I know,
+	     * only the ingredient was *supposed* to change) then the
+	     * recipe will still be out-of-date.
+	     */
+	    if (!now)
+		time(&now);
 
 	    /*
 	     * The file's last-modified time has changed since we last saw it.
@@ -154,7 +164,6 @@ stat_cache_fingerprint(path, cp)
 	    s = fp_fingerprint(path);
 	    if (!s)
 		goto fp_not_useful;
-	    time(&now);
 	    if (str_equal(fp->contents_fingerprint, s))
 	    {
 		/*
