@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1994 Peter Miller.
+ *	Copyright (C) 1994, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -15,7 +15,7 @@
  *
  *	You should have received a copy of the GNU General Public License
  *	along with this program; if not, write to the Free Software
- *	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
  *
  * MANIFEST: interface definition for cook/stat.cache.c
  */
@@ -26,8 +26,8 @@
 #include <ac/time.h>
 #include <str.h>
 
-time_t stat_cache_oldest _((string_ty *));
-time_t stat_cache_newest _((string_ty *));
+time_t stat_cache_oldest _((string_ty *, int));
+time_t stat_cache_newest _((string_ty *, int));
 void stat_cache_set _((string_ty *, time_t, int));
 void stat_cache_clear _((string_ty *));
 
