@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1990, 1991, 1992, 1993, 1997 Peter Miller;
+ *	Copyright (C) 1990, 1991, 1992, 1993, 1997, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -32,7 +32,7 @@ struct opcode_list_ty; /* existence */
 enum stmt_result_ty
 {
 	STMT_OK = 0,
-	STMT_ERROR = -3,
+	STMT_ERROR = -3
 };
 typedef enum stmt_result_ty stmt_result_ty;
 
