@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997 Peter Miller;
+ *	Copyright (C) 1997, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -28,7 +28,8 @@
 struct string_ty; /* existence */
 struct string_list_ty; /* existence */
 
-void strip_dot _((struct string_ty **));
+string_ty *strip_dot_inner _((struct string_ty *));
+string_ty *strip_dot _((struct string_ty *));
 void strip_dot_list _((struct string_list_ty *));
 
 #endif /* COOK_STRIP_DOT_H */
