@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1994, 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1994, 1997, 1998, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -64,7 +64,12 @@ usage()
 	char		*progname;
 
 	progname = progname_get();
-	fprintf(stderr, "Usage: %s [ <option>... ][ <filename>... ]\n", progname);
+	fprintf
+	(
+		stderr,
+		"Usage: %s [ <option>... ][ <filename>... ]\n",
+		progname
+	);
 	fprintf(stderr, "       %s -Help\n", progname);
 	exit(1);
 }
@@ -90,11 +95,11 @@ main(argc, argv)
 	case arglex_token_help:
 		help((char *)0, usage);
 		exit(0);
-	
+
 	case arglex_token_version:
 		version();
 		exit(0);
-	
+
 	default:
 		break;
 	}
@@ -154,7 +159,7 @@ main(argc, argv)
 				error_intl
 				(
 					0,
-					i18n("may only name standard input once")
+				       i18n("may only name standard input once")
 				);
 				usage();
 			}
