@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	cook - file construction tool
-#	Copyright (C) 1993-1997, 1999, 2001, 2002 Peter Miller;
+#	Copyright (C) 1993-1997, 1999, 2001-2003 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -156,6 +156,15 @@ lib/*/*/*.pic)
 	# in the User Guide
 	;;
 
+lib/*/building/*)
+	;;
+lib/*/lsm/*)
+	;;
+lib/*/readme/*)
+	;;
+lib/*/release/*)
+	;;
+
 lib/*/*/main.*)
 	macros=`echo $file | sed 's|^lib/.*/.*/main.\(.*\)$|\1|'`
 	stem=`echo $file | sed 's|^lib/\(.*/.*/main\).*$|\1|'`
