@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	cook - file construction tool
-#	Copyright (C) 1993, 1994, 1995, 1996, 1997, 1999, 2001 Peter Miller;
+#	Copyright (C) 1993-1997, 1999, 2001, 2003 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -32,14 +32,6 @@ echo 'URL: http://www.canb.auug.org.au/~millerp/cook/'
 echo 'BuildRoot: /tmp/cook-build-root'
 echo 'Icon: cook.gif'
 
-prefix=/usr
-#
-# RPM only has install-time relocatable packages.  It has no support for
-# build-time relocatable packages.  Therefore, we must NOT specify a Spec
-# prefix, or the installed locations will not match the built locations.
-#
-#echo "Prefix: $prefix"
-
 echo ''
 
 cat << 'fubar'
@@ -98,19 +90,23 @@ Group: Development/Building
 Cook documentation in DVI format.
 
 %prep
-fubar
+%setup -q
+%configure
+grep datadir config.status
 
-#
-# set the prefix here
-#
-echo '%setup'
-echo "./configure --prefix=$prefix"
-echo ''
-echo '%build'
-echo 'make'
-echo ''
-echo '%install'
-echo 'make RPM_BUILD_ROOT=$RPM_BUILD_ROOT install'
+%build
+make
+
+%install
+test -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != / && rm -rf "$RPM_BUILD_ROOT"
+make RPM_BUILD_ROOT=$RPM_BUILD_ROOT install
+
+%clean
+test -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != / && rm -rf "$RPM_BUILD_ROOT"
+
+%files
+%defattr (-,root,root)
+fubar
 
 #
 # remember things for the %files section
@@ -125,7 +121,7 @@ remember_prog()
 	if eval "test \"\${prog_${1}-no}\" != yes"
 	then
 		eval "prog_${1}=yes"
-		binfiles="$binfiles $prefix/bin/${1}"
+		binfiles="$binfiles %_prefix/bin/${1}"
 	fi
 }
 
@@ -163,7 +159,7 @@ do
 
 	lib/*.po)
 		stem=`echo $file | sed 's|^lib/\(.*\)\.po$|\1|'`
-		dst="$prefix/lib/cook/$stem.mo"
+		dst="%_prefix/lib/cook/$stem.mo"
 		files="$files $dst"
 		;;
 
@@ -176,36 +172,38 @@ do
 		# some versions of RPM gzip man pages for free, so use a
 		# wild card to find them, rather than an exact name.  Sigh.
 		stem=`echo $file | sed 's|^lib/||'`
-		files="$files $prefix/share/cook/${stem}*"
+		files="$files %_prefix/share/cook/${stem}*"
 
 		case $file in
 		lib/en/*)
 			stem2=`echo $file | sed 's|^lib/en/||'`
-			files="$files $prefix/man/${stem2}*"
+			files="$files %_prefix/share/man/${stem2}*"
 			;;
 		esac
 		;;
 
 	lib/*/*/main.*)
 		stem=`echo $file | sed 's|^lib/\(.*\)/main.*$|\1|'`
-		psdocs="$psdocs $prefix/share/cook/$stem.ps"
-		dvidocs="$dvidocs $prefix/share/cook/$stem.dvi"
-		txtdocs="$txtdocs $prefix/share/cook/$stem.txt"
+		psdocs="$psdocs %_prefix/share/cook/$stem.ps"
+		dvidocs="$dvidocs %_prefix/share/cook/$stem.dvi"
+		txtdocs="$txtdocs %_prefix/share/cook/$stem.txt"
 		;;
 
 	lib/*)
 		rest=`echo $file | sed 's|^lib/||'`
-		dst="$prefix/share/cook/$rest"
+		dst="%_prefix/share/cook/$rest"
 		files="$files $dst"
 		;;
 
+	script/*.in)
+		rest=`echo $file | sed 's|^script/\(.*\)\.in|\1|'`
+		binfiles="$binfiles %_prefix/bin/$rest"
+		;;
 	*)
 		;;
 	esac
 done
-
-echo ''
-echo '%files'
+(
 for file in $binfiles
 do
 	echo "%attr(0755,root,bin) $file"
@@ -218,6 +216,7 @@ for file in $txtdocs
 do
 	echo "%attr(0644,root,bin) $file"
 done
+) | sort +1
 
 echo ''
 echo '%files psdocs'
@@ -232,7 +231,3 @@ for file in $dvidocs
 do
 	echo "%attr(0644,root,bin) $file"
 done
-
-echo ''
-echo '%clean'
-echo 'rm -rf $RPM_BUILD_ROOT'
