@@ -25,7 +25,7 @@
 #include <sys/stat.h>
 
 #include <error_intl.h>
-#include <os.h>
+#include <os_interface.h>
 
 /*
  *  NAME
