@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1994, 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1994, 1997, 1998, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -175,7 +175,7 @@ byte()
 		case INPUT_EOF:
 			bol = 1;
 			break;
-		
+
 		case '\n':
 			++line_number;
 			bol = 1;
@@ -228,7 +228,7 @@ byte_undo(c)
 	case '\n':
 		--line_number;
 		/* fall through... */
-	
+
 	default:
 		input_ungetc(input, c);
 		break;
@@ -483,7 +483,12 @@ gram_lex()
 				break;
 			}
 			gram_lval.lv_line =
-				blob_alloc(sa_close(), input_filename(input), linum);
+				blob_alloc
+				(
+					sa_close(),
+					input_filename(input),
+					linum
+				);
 			token = COMMAND;
 			goto done;
 
@@ -555,7 +560,12 @@ gram_lex()
 				colon_special = 1;
 			}
 			gram_lval.lv_line =
-				blob_alloc(sa_close(), input_filename(input), linum);
+				blob_alloc
+				(
+					sa_close(),
+					input_filename(input),
+					linum
+				);
 			goto done;
 
 		case ' ':
@@ -614,7 +624,7 @@ gram_lex()
 			byte_undo(c);
 			c = '+';
 			/* fall through... */
-		
+
 		default:
 			normal:
 			sa_open();
@@ -665,12 +675,17 @@ gram_lex()
 					if (paren_depth >= paren_max)
 					{
 						paren_max = paren_max * 2 + 16;
-						paren = mem_change_size(paren, paren_max);
+						paren =
+							mem_change_size
+							(
+								paren,
+								paren_max
+							);
 					}
 					paren[paren_depth++] = /*(*/')';
 					c = byte();
 					continue;
-				
+
 				case /*(*/')':
 				case /*{*/'}':
 					sa_char(c);
@@ -689,7 +704,12 @@ gram_lex()
 					if (paren_depth >= paren_max)
 					{
 						paren_max = paren_max * 2 + 16;
-						paren = mem_change_size(paren, paren_max);
+						paren =
+							mem_change_size
+							(
+								paren,
+								paren_max
+							);
 					}
 					paren[paren_depth++] = /*{*/'}';
 					c = byte();
@@ -707,7 +727,7 @@ gram_lex()
 					str_free(s);
 					++within_define;
 					break;
-				
+
 				case ENDDEF:
 					str_free(s);
 					--within_define;
@@ -715,9 +735,14 @@ gram_lex()
 
 				case IF:
 					gram_lval.lv_line =
-						blob_alloc(s, input_filename(input), linum);
+						blob_alloc
+						(
+							s,
+							input_filename(input),
+							linum
+						);
 					break;
-				
+
 				case VPATH:
 					colon_special = 0;
 					break;
