@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1994, 1997 Peter Miller;
+ *	Copyright (C) 1994, 1997, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -189,11 +189,21 @@ stmt_assign_alloc(override, lhs, op, rhs)
 		if (op == stmt_assign_op_normal)
 		{
 			trace(("mdef %s\n", lhs2->list[j]->text->str_text));
-			string_list_append_unique(&this->mdef, lhs2->list[j]->text);
+			string_list_append_unique
+			(
+				&this->mdef,
+				lhs2->list[j]->text
+			);
 		}
 		string_list_append_unique(&this->cdef, lhs2->list[j]->text);
 		if (op == stmt_assign_op_plus)
-			string_list_append_unique(&this->ref, lhs2->list[j]->text);
+		{
+			string_list_append_unique
+			(
+				&this->ref,
+				lhs2->list[j]->text
+			);
+		}
 	}
 	rhs2 = blob_list_alloc();
 	variable_rename_list(rhs, rhs2, &this->ref, VAREN_QUOTE_SPACES);
@@ -391,7 +401,7 @@ default_setting(name)
 	++linum;
 	if (!builtin)
 		builtin = str_from_c("builtin");
-	lhs = blob_alloc(str_copy(name), builtin, linum); 
+	lhs = blob_alloc(str_copy(name), builtin, linum);
 	rhs = blob_list_alloc();
 	data = symtab_query(stp, name);
 	if (data)
