@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1994 Peter Miller.
+ *	Copyright (C) 1994, 1997 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -15,7 +15,7 @@
  *
  *	You should have received a copy of the GNU General Public License
  *	along with this program; if not, write to the Free Software
- *	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
  *
  * MANIFEST: interface definition for make2cook/stmt/if.c
  */
@@ -26,6 +26,6 @@
 #include <blob.h>
 #include <stmt.h>
 
-stmt_ty *stmt_if_alloc _((blob_ty *, stmt_ty *, stmt_ty *));
+stmt_ty *stmt_if_alloc _((blob_list_ty *, stmt_ty *, stmt_ty *));
 
 #endif /* MAKE2COOK_STMT_IF_H */
