@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1994 Peter Miller.
+ *	Copyright (C) 1994, 1997 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -15,7 +15,7 @@
  *
  *	You should have received a copy of the GNU General Public License
  *	along with this program; if not, write to the Free Software
- *	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
  *
  * MANIFEST: interface definition for make2cook/stmt/rule.c
  */
@@ -29,8 +29,10 @@
 extern int stmt_rule_default_history;
 
 stmt_ty *stmt_rule_alloc _((blob_list_ty *lhs, int op, blob_list_ty *rhs,
-	blob_list_ty *predicate));
-void stmt_rule_append _((stmt_ty *, blob_ty *));
+	blob_list_ty *flags, blob_list_ty *predicate,
+	blob_list_ty *single_thread));
+void stmt_rule_body _((stmt_ty *, stmt_ty *));
+void stmt_rule_context _((stmt_ty *));
 stmt_ty *stmt_rule_default _((int));
 
 #endif /* MAKE2COOK_STMT_RULE_H */
