@@ -36,7 +36,8 @@
 #define VAREN_NO_QUOQUO 4	/* don't quote doutes */
 
 void variable_rename _((blob_ty *, blob_list_ty *, string_list_ty *, int));
-void variable_rename_list _((blob_list_ty *, blob_list_ty *, string_list_ty *, int));
+void variable_rename_list _((blob_list_ty *, blob_list_ty *, string_list_ty *,
+    int));
 void variable_archive _((string_ty *target, string_ty *member));
 
 /* for use by vargram */
