@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1992, 1993, 1994, 1997, 1998 Peter Miller;
+ *	Copyright (C) 1992, 1993, 1994, 1997, 1998, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -21,11 +21,11 @@
  */
 
 #include <ac/ctype.h>
-#include <ac/stdio.h>
 #include <ac/stdlib.h>
 #include <ac/unistd.h>
 
 #include <error_intl.h>
+#include <input/file_text.h>
 #include <mem.h>
 #include <preprocess.h>
 #include <str.h>
@@ -320,35 +320,17 @@ static void
 scan(ifn)
 	string_ty	*ifn;
 {
-	FILE		*ifp;
+	input_ty	*ifp;
 	size_t		pos;
 	static size_t	max;
 	static char	*line;
 	long		lino;
 	int		c;
 	string_ty	*ifn2;
-	sub_context_ty	*scp;
 
 	trace(("scan(ifn = \"%s\")\n{\n"/*}*/, ifn ? ifn->str_text : "-"));
-	if (ifn)
-	{
-		ifp = fopen(ifn->str_text, "r");
-		if (!ifp)
-		{
-			scp = sub_context_new();
-			sub_errno_set(scp);
-			sub_var_set(scp, "File_Name", "%S", ifn);
-			fatal_intl(scp, i18n("open $filename: $errno"));
-		}
-	}
-	else
-	{
-		scp = sub_context_new();
-		ifn = subst_intl(scp, i18n("standard input"));
-		sub_context_delete(scp);
-		ifp = stdin;
-	}
-	ifn2 = str_copy(ifn);
+	ifp = input_file_text_open(ifn);
+	ifn2 = str_copy(input_filename(ifp));
 
 	lino = 1;
 	resync(ofp, ifn2, lino);
@@ -361,17 +343,10 @@ scan(ifn)
 			max += 100;
 			line = mem_change_size(line, max);
 		}
-		c = getc(ifp);
+		c = input_getc(ifp);
 		switch (c)
 		{
-		case EOF:
-			if (ferror(ifp))
-			{
-				scp = sub_context_new();
-				sub_errno_set(scp);
-				sub_var_set(scp, "File_Name", "%S", ifn);
-				fatal_intl(scp, i18n("read $filename: $errno"));
-			}
+		case INPUT_EOF:
 			if (!pos)
 				break;
 			/* fall through... */
@@ -385,17 +360,7 @@ scan(ifn)
 				fputs(line, ofp);
 				putc('\n', ofp);
 			}
-			if (ferror(ofp))
-			{
-				scp = sub_context_new();
-				sub_errno_set(scp);
-				sub_var_set(scp, "File_Name", "%S", ofn);
-				fatal_intl
-				(
-					scp,
-					i18n("write $filename: $errno")
-				);
-			}
+			fflush_and_check(ofp, ofn->str_text);
 			lino++;
 			pos = 0;
 			continue;
@@ -407,13 +372,7 @@ scan(ifn)
 		break;
 	}
 
-	if (ifp != stdin && fclose(ifp))
-	{
-		scp = sub_context_new();
-		sub_errno_set(scp);
-		sub_var_set(scp, "File_Name", "%S", ifn);
-		fatal_intl(scp, i18n("close $filename: $errno"));
-	}
+	input_delete(ifp);
 	str_free(ifn2);
 	trace((/*{*/"}\n"));
 }
@@ -458,14 +417,7 @@ preprocess(ifile, ofile)
 	if (ofile)
 	{
 		ofn = str_from_c(ofile);
-		ofp = fopen(ofn->str_text, "w");
-		if (!ofp)
-		{
-			scp = sub_context_new();
-			sub_errno_set(scp);
-			sub_var_set(scp, "File_Name", "%S", ofn);
-			fatal_intl(scp, i18n("open $filename: $errno"));
-		}
+		ofp = fopen_and_check(ofn->str_text, "w");
 	}
 	else
 	{
@@ -489,20 +441,9 @@ preprocess(ifile, ofile)
 	/*
 	 * close up and go home
 	 */
-	if (fflush(ofp))
-	{
-		scp = sub_context_new();
-		sub_errno_set(scp);
-		sub_var_set(scp, "File_Name", "%S", ofn);
-		fatal_intl(scp, i18n("write $filename: $errno"));
-	}
-	if (ofp != stdout && fclose(ofp))
-	{
-		scp = sub_context_new();
-		sub_errno_set(scp);
-		sub_var_set(scp, "File_Name", "%S", ofn);
-		fatal_intl(scp, i18n("close $filename: $errno"));
-	}
+	fflush_and_check(ofp, ofn->str_text);
+	if (ofp != stdout)
+		fclose_and_check(ofp, ofn->str_text);
 	str_free(ofn);
 	ofp = 0;
 	ofn = 0;
