@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	cook - file construction tool
-#	Copyright (C) 1999 Peter Miller;
+#	Copyright (C) 1999, 2003 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -92,18 +92,31 @@ if test $? -ne 0 ; then no_result; fi
 chmod ogu-w a b/.cook.fp
 if test $? -ne 0 ; then no_result; fi
 
+# Solaris delays inode changes for a long time
+# make sure the permissions are set solid before the next action.
+sync
+
 $bin/cook -nl -fp-update
 if test $? -ne 0 ; then fail; fi
 
 # Because a is read-only doesn't mean that a/.cook.fp is read-only,
-# and it gets over-writte.
+# and it gets over-written.
+if test '!' -s a/.cook.fp
+then
+	# a/.cook.fp is empty and it shouldn't be
+	fail
+fi
+
 # However b/.cook.fp is readonly (even though b is writable), and it
 # *doesn't* get over-written (on an open-for-writing failure it doesn't
 # backtrack and try to unlink again).
+if test -s b/.cook.fp
+then
+	# b/.cook.fp isn't empty and it should be
+	fail
+fi
 
-test -s a/.cook.fp || fail
-test -s b/.cook.fp && fail
-
+# There should be 4 entries in the file.
 test `wc .cook.fp|awk '{print$1}'` -eq 4 || fail
 
 $bin/cook -nl -fp-update
